---
date: 2020-11-17
title: "BCGov - Government of British Columbia Canada"
description: "BCGov's Verifiable Organizations Network (VON) is a community effort to establish a better way to find, issue, store and share trustworthy data about organizations."
excerpt: >
  "Digital technologies are transforming the way British Columbians live, work and play. To meet their changing expectations, government’s transformation is also underway. It’s about using modern tools and technologies to deliver the services people want and maximizing the power of data to improve the services people need." 
permalink: /government/canada/bcgov/
redirect_from: /public-sector/canada/
categories: ["Government"]
tags: ["Trust Framework","Canada","Verifiable Organizations Network","Trinsic","IIW","DID","Aries","Verifiable Credentials","W3C","Trust over IP","Indy"]
header:
  image: /images/bcgov-header.webp
  teaser: /images/bcgov-teaser.webp
updated: 2020-11-19
---

* [gov.bc.ca](https://www2.gov.bc.ca/gov/content/home) - The official website of the Government of British Columbia.
  > The Government of B.C. is made up of ministries, agencies and Crown corporations. Browse ministry, agency and Crown corporation websites for the latest news, service plans, publications and more.
* [news.gov.bc.ca](https://news.gov.bc.ca/)
* [publications.gov.bc.ca](https://www.publications.gov.bc.ca/)
* [British Columbia - Digital Government](https://digital.gov.bc.ca/) - B.C.’s digital future ([source](https://github.com/bcgov/digital.gov.bc.ca))
  > Digital technologies are transforming the way British Columbians live, work and play. To meet their changing expectations, government’s transformation is also underway. It’s about using modern tools and technologies to deliver the services people want and maximizing the power of data to improve the services people need.

## Developers

* [BCDevExchange](https://bcdevexchange.org/) - ([source](https://github.com/bcgov/bcdevexchange))
  > We're a supportive community in British Columbia, Canada enabling the government to deliver better digital services.
* [DevHub](https://developer.gov.bc.ca/) ([source](https://github.com/bcgov/devhub-resources)) - One place that brings together resources to help build digital products for the BC Government
* [bcgov/mobile-signing-service](https://github.com/bcgov/mobile-signing-service/)
  > This is the Agent component to the BCDevX Mobile App Signing Service. The Signing Service is designed to be a self-serve system that enables development teams to sign and deploy build artifacts in a secure environment.
* [Shared Resources](https://bcgov.github.io/common-components-wiki/) - [source](https://github.com/bcgov/common-components-wiki)
  > The Common Components team is working on ways to reduce the time and cost of delivering digital products and services. We plan to achieve this by making it easy to find, onboard to and use components like code and microservices that solve common problems across government. Our work is a priority action in BC’s Digital Framework.
* [Digital Toolkit](https://digital-toolkit.pathfinder.gov.bc.ca/) ([source](https://github.com/bcgov/digital-toolkit))
  > The BCGov Digital Toolkit is the reference repository for digital best practices across our teams

## Verifiable Organizations Network

* [VonX](https://vonx.io/) - Global digital trust for organizations
  > The Verifiable Organizations Network (VON) is a community effort to establish a better way to find, issue, store and share trustworthy data about organizations—locally and around the globe. Community partners are using jointly developed software components to enable the digitization of government-issued public credentials—registrations, permits, and licenses. Currently, VON components are based on Hyperledger Indy distributed ledger technology. 
* [Verifiable Organizations Network]({{ site.baseurl }}/government/canada/bcgov/von/hgf-2018-production-government-deployment-hyperledger-indy/) - A Production Government Deployment of Hyperledger Indy Presentation by John Jordan and Stephen Curran at HGF 2018 (Transcript)
  > VON's founding members are governments who are, by law, trusted issuers of data about organizations. The Province of British Columbia, Province of Ontario and the Government of Canada have come together to create the initial services needed to establish VON.
  >
  > VON's founders have delivered new Indy-based open source components which form VON's backbone. TheOrgBook is a publicly accessible repository of verifiable claims about organizations. VON-X enables services to verify and issue credentials. 
* [bcgov/TheOrgBook](https://github.com/bcgov/TheOrgBook) - A public repository of verifiable claims about organizations. A key component of the Verifiable Organization Network.
  > OrgBook BC is a deployment of an underlying software component called a Verifiable Credential Registry (VCR). A VCR is more general component that can drive OrgBooks (repositories of information about registered organizations), and other repositories of verifiable information across a variety of use cases, including education, government services, public works projects and many more. The first generation of OrgBook BC was built on top of the software whose source code is in this repository. The current iteration of OrgBook BC is powered by the Aries Verifiable Credential Registry (VCR) (Aries VCR). TheOrgBook was implemented using custom protocols defined locally by the Verifiable Organizations Network (VON) team here in BC, Aries VCR is based on Hyperledger Aries protocols defined by a global community at the Linux Foundation.
* [bcgov/von](https://github.com/bcgov/von) - Verifiable Organizations Network
* [bcgov/von-ledger-explorer](https://github.com/bcgov/von-ledger-explorer) - The VON Ledger Explorer
  > BCOVRIN to Google Sheets Connector
* [bcgov/issuer-kit-demo-verifier-chat](https://github.com/bcgov/issuer-kit-demo-verifier-chat) - Issuer Kit Demo Verifier Chat  
* [bcgov/BCSC-SS](https://github.com/bcgov/BCSC-SS)
  > Resources to make it easier for public organizations to offer the widely used BC Services Card a secure and verified government issued identity card as a login option for online services.
* [bcgov/orgbook-api](https://github.com/bcgov/orgbook-api) -  Autocomplete component + Various developer tools and documentation for using the OrgBook API


## Demonstrators
### Indy Catalyst - AgentBook - Agent to Agent Messaging Technology

* [bcgov/aries-vcr](https://github.com/bcgov/aries-vcr)
  > Hyperledger Indy Catalyst is a set of application level software components designed to accelerate the adoption of trustworthy entity to entity1 communications based on Decentralized Identity / Self-Sovereign Identity technology and architecture. Indy Catalyst is builds upon globally available open standards and open source software. At present, Indy Catalyst builds upon Hyperledger Indy, common enterprise open source software, frameworks and patterns such as PostgreSQL, Python, Angular and RESTful APIs. Efforts will be taken to design the software to facilitate the incorporation of evolving open standards and technology. The impetus for Indy Catalyst came from the Verifiable Organizations Network (VON) project. More information about VON can be found at vonx.io
* [bcgov/orgbook-configurations](https://github.com/bcgov/orgbook-configurations) -  Build and Deployment Configurations for the Indy-Catalyst version of the OrgBook 
  > This repository contains the openshift-developer-tools compatible OpenShift configurations for the indy-catalyst instance of the OrgBook.
* [BC Gov – Indy Catalyst Agent + Agent Framework: What are they?](https://iiw.idcommons.net/GC_Gov_%E2%80%93_Indy_Catalyst_Agent_%2B_Agent_Framework:_What_are_they%3F)
  * [Indy Catalyst Agent (Nick/Andrew – BC Gov)](https://docs.google.com/presentation/d/12SY33tfD0R_33SEx6T6JxtOT6NBID03wsqiMnvDp8ic/edit?usp=sharing) ([bcgov/indy-catalyst/](https://github.com/bcgov/indy-catalyst/))
    > What is an "Agent"?
    > 1. It acts as a fiduciary on behalf of a single identity owner (or, for agents of things like IoT devices, pets, and similar things, a single *controller*)
    > 2. It holds cryptographic keys that uniquely embody its delegated authorization.
    > 3. It interacts using interoperable agent-to-agent protocols.
* [bcgov/von-bc-registries-agent-configurations](https://github.com/bcgov/von-bc-registries-agent-configurations) -  Build and Deployment Configurations for the Indy-Catalyst version of the BC Registries Agent 
  > This repository contains the openshift-developer-tools compatible OpenShift configurations for the indy-catalyst compatible instance of the von-bc-registries-agent.

### GreenLight - Decentralized Workflow Technology
* [bcgov/von-network](https://github.com/bcgov/von-network) - A portable development level Indy Node network.
  > A portable development level Indy Node network, including a Ledger Browser. The Ledger Browser (for example the BC Gov's Ledger for the GreenLight Demo Application) allows a user to see the status of the nodes of a network and browse/search/filter the Ledger Transactions.
* [bcgov/greenlight](https://github.com/bcgov/greenlight) -  A demonstration of the verifiable organization network showing a new restaurant gathering the permits necessary to open. 
  > GreenLight (an instance of decentralized workFlow) demonstrates a basic application for deploying the VON-X library, in order to enable issuer registration, claims verification, and credential submission to TheOrgBook. It includes Docker tooling for deployment of the application behind a Caddy reverse proxy.

### Proof of Concept Registration

* [SafeEntryBC](https://safeentrybc.vonx.io/)
  > Allowing Businesses and Citizen's to create "Safe Entry Points" that require the presentation and proof of a set of digitally verifiable credentials in order to authorize access.
  > 
  > This is an instance of [bcgov/dts-esr-demo](https://github.com/bcgov/dts-esr-demo)
* [BC Essential Services Gateway](https://esg.vonx.io/)
  > Allowing Businesses to register as an Essential Service and in turn be able to issue Essential Service credentials to their employees.
  > 
  > This is an instance of [bcgov/dts-safe-entry-demo](https://github.com/bcgov/dts-safe-entry-demo)

### Safe Entry Points 

instances of [bcgov/vc-visual-verifier](https://github.com/bcgov/vc-visual-verifier)

* [Traveller Safe Entry](https://lngpipeline-camp.vonx.io/)
  > Demonstrates how digitally verifiable credentials can be used to authorize access to or through a point of entry.
* [Essential Service Safe Entry](https://long-term-care-facility.vonx.io/)
  > Demonstrates how digitally verifiable credentials can be used to provide essential services workers with authorized access to a location or facility.

### IIW Book

<blockquote class="twitter-tweet"><p lang="en" dir="ltr">So far the killer demo of <a href="https://twitter.com/hashtag/IIW?src=hash&amp;ref_src=twsrc%5Etfw">#IIW</a> 28 is “IIWBook” from <a href="https://twitter.com/jljordan42?ref_src=twsrc%5Etfw">@jljordan42</a> &amp; BC Gov &amp; Streetcred teams. First you get a <a href="https://twitter.com/hashtag/verifiablecredential?src=hash&amp;ref_src=twsrc%5Etfw">#verifiablecredential</a> of your verified email address and IIW attendance, then you can create peer-to-peer DID-to-DID connections with any other IIWBook user. Mind blown! <a href="https://t.co/2exkD3xdXP">pic.twitter.com/2exkD3xdXP</a></p>&mdash; Drummond Reed (@drummondreed) <a href="https://twitter.com/drummondreed/status/1123647138200600576?ref_src=twsrc%5Etfw">May 1, 2019</a></blockquote> <script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script> 

* [IIW Book](https://github.com/bcgov/iiwbook)
* [Highlights of Internet Identity Workshop (IIW) #28](https://docs.google.com/presentation/d/1jG4HxFhzQoKBp7xqD_8A3L1DtJQ-zKFbJn-IVQ9lMvk/htmlpresent)
  > The BC Gov team led a killer agent interop demo
  > 
  > - https://iiw.vonx.io/ to start the demo
  > - You can use any of 3 different agent/wallet apps
  > - First you get a verifiable credential of your email address
  > - Then you get a VC that you were an IIW attendee
  > - Then you were added to the IIWBook directory
  > - Then you could create your own private peer-to-peer connection with any other IIWBook member
* [IIW Book! Come get a REAL IIW attendance verification credential and prove it to your IIW friends using your phone!](https://iiw.idcommons.net/IIW_Book!_Come_get_a_REAL_IIW_attendance_verification_credential_and_prove_it_to_your_IIW_friends_using_your_phone!)
  >  Key understanding: a demonstration of an identity authentication, issuing, relying party connection and document/chat exchange using authenticated identities. 
* [BC Gov , MATTR, STREETCRED – IIW Book Redux](https://iiw.idcommons.net/BC_Gov_,_MATTR,_STREETCRED_%E2%80%93_IIW_Book_Redux)
  > There was continued discussion about a Connectathon last February where 6 different systems were verified as connecting. Evernym was not a system that passed, but this was not held as a lack of ability as much as direction of activities – they had more important features they were working on. 

Link to presentation provided by John Jordon on Tuesday (Part 1) & Wednesday (Redux): [http://IIW.vonx.io](http://IIW.vonx.io)

* [The VON IIW 28 Demonstration: IIWBook](https://vonx.io/how_to/iiwbook)
  > In late March 2019, the VON team created AgentBook to demonstrate the interoperability of independently created agents. These agents were able to successfully establish DID-based communication channels. Now, with IIWBook, we’ve added a (literal) new layer by extending the core of AgentBook with the ability to exchange verifiable credentials. Even more exciting, through collaboration with Streetcred.id and Spark New Zealand, we have a mobile agent (or two!).

{% include video id="bZrWAsD42-I" provider="youtube" %}

## Other Repositories

* [bcgov/BC-Policy-Framework-For-GitHub](https://github.com/bcgov/BC-Policy-Framework-For-GitHub) - Policy information for BC Government employees using GitHub
  > This repo's content is focused on providing information, examples and guidelines to facilitate the creation and governance of BCGov Open Source projects. We don't want to duplicate the good work GitHub has done with their own online guides. Our focus is giving BC Government people and projects the information they need to get started on GitHub while remaining compliant with BC standards and policies.
* [bcgov/design-system](https://github.com/bcgov/design-system) - British Columbia Government Design System for Digital Services
  > It’s a collection of digital resources and tools – including a library of reusable UI/interface components and design patterns. The system makes it easier and faster to build custom B.C. government websites and applications.
* [api-guidelines](https://github.com/bcgov/api-guidelines) - BC Government API Guidelines
  > Purpose : The purpose of these guidelines is to promote consistency and provide guidance around the use of Application Programming Interfaces (APIs) across the BC government, and to enable exchange and integration of data between systems, agencies, businesses and citizens.
* [digital-principles](https://github.com/bcgov/digital-principles) - A set of principles to guide the Province of BC's continued Digital Government evolution
  > The Digital Principles are meant to guide the work of individual public servants and vendor partners as the Province of British Columbia continues to evolve into a Digital Government. This includes everything from the day-to-day work of individuals to the design, development and delivery of digital products and services.
* [bcgov/digital-policy](https://github.com/bcgov/digital-policy)
  > BC's Digital Framework (currently an alpha version) drives a coordinated, intentional approach to support all public service employees as we transition into a digital government that meets the internet-era needs and expectations of British Columbians. A key action outlined in the Digital Framework is to “create a new digital and data policy framework to guide the work of public servants.” A core product team within the Office of the Chief Information Officer (OCIO) is taking an agile, principle-based approach to co-developing a new Digital Policy Framework. This policy framework covers all aspects of BC government information management (IM) and information technology (IT) management.
* [bcgov/digital_marketplace](https://github.com/bcgov/digital_marketplace)
  > The Digital Marketplace is a web application that administers British Columbia's Code With Us and Sprint With Us procurement programs. It enables (1) public sector employees to create and publish procurement opportunities, and (2) vendors to submit proposals to these opportunities.
* [Technology Code of Practice](https://github.com/bcgov/Technology-Code-of-Practice)
  The BC Technology Code of Practice, being developed pursuant to BC's Digital Framework and the priority actions therein, is a DRAFT set of criteria to help the BC Government design, build, and buy better technology. The Code is envisioned to be used as a cross-government agreed standard in government's new technology funding review process.

### Trust over IP

* [bcgov/a2a-trust-over-ip-configurations](https://github.com/bcgov/a2a-trust-over-ip-configurations) - OpenShift build and deployment configurations for the Access to Audio Trust Over IP components. 
  > This repository contains the openshift-developer-tools compatible OpenShift configurations to customize the builds and deployments of vc-authn-oidc for use with the A2A Trust Over IP project.

### Indy

* [bcgov/indy-sdk-postgres-storage](https://github.com/bcgov/indy-sdk-postgres-storage) - PostgreSQL plug-in for use with the indy-sdk
* [bcgov/indy-email-verification](https://github.com/bcgov/indy-email-verification)

```json
{
  "id": "verified-email",
  "subject_identifier": "email",
  "configuration": {
    "name": "verified-email",
    "version": "1.0",
    "requested_attributes": [
      {
        "name": "email",
        "label": "Verified Email",
        "restrictions": [          
          {
            "schema_name": "verified-email",
            "schema_version": "1.2.2",
            "issuer_did": "MTYqmTBoLT7KLP5RNfgK3b"
          },
          {
            "schema_name": "verified-email",
            "schema_version": "1.2.3",
            "issuer_did": "MTYqmTBoLT7KLP5RNfgK3b"
          }
        ]
      }
    ],
    "requested_predicates": []
  }
}
```


### Agents

* [Agent Framework (Tomislav Markovski – Streetcred ID)](https://drive.google.com/file/d/1HDc_OBbT-0ggGFhyqqmw3TALrxI0K51c/view?usp=sharing)
  > Library for building SSI agent services w/ .NET Core - [streetcred-id/agent-framework](https://github.com/trinsic-id/agent-framework) (now [hyperledger/aries-framework-dotnet](https://github.com/hyperledger/aries-framework-dotnet))
* [bcgov/aries-cloudagent-container](https://github.com/bcgov/aries-cloudagent-container) -  Runnable Docker image for the Hyperledger Aries Cloudagent 
* [bcgov/von-personal-agent](https://github.com/bcgov/von-personal-agent) - A personal agent for the von network.
* [bcgov/VON-ESB-DRS-Agent](https://github.com/bcgov/VON-ESB-DRS-Agent) - Piloting the Dispute Resolution Suite with connections to the OrgBook
* [bcgov/von-agent-template](https://github.com/bcgov/von-agent-template) - Template for a von-x based agent
* [bcgov/von-bc-registries-agent](https://github.com/bcgov/von-bc-registries-agent)
  > Components for plugging the BC Registries into the verifiable organizations network.
* [bcgov/von_agent](https://github.com/bcgov/von_agent) Forked from PSPC-SPAC-buyandsell/von_agent - VON agents using indy-sdk
* [bcgov/von-bc-registries-audit](https://github.com/bcgov/von-bc-registries-audit) - Audit scripts for aries vcr/orgbook and bc registries issuer 
* [bcgov/aries-cloudcontroller-node](https://github.com/bcgov/aries-cloudcontroller-node)


### Verifiable Credentials

* [Essential Services Delivery coordination using Digitally Verifiable Credentials](https://github.com/bcgov/essential-services-delivery)
  > This repository contains the build, deployment, and application configurations needed to pull a number of separate applications into a single environment and deploy them as a group of interrelated services.
* [bcgov/vc-visual-verifier](https://github.com/bcgov/vc-visual-verifier) - Verifiable Credential Visual Verifier
* [Verifiable Credential Authentication with OpenID Connect (VC-AuthN OIDC)](https://github.com/bcgov/vc-authn-oidc)
  > The integration this document defines is how holders of verifiable credentials can leverage these to authenticate with parties. Note, how the holder became in possession of supported verifiable credentials is out of scope for this integration.
  > 
  > Like any new technology there is adoption required of new concepts, this particular integration aims to provide an easy integration path that allows parties to start leveraging the power of verifiable credentials for user authentication in a non-disruptive fashion. This is achieved by extending the vastly popular OpenID Connect family of specifications.

#### Credential Issuer Services

instances of [bcgov/issuer-kit](https://github.com/bcgov/issuer-kit)

* [Unverified Person Issuer](https://openvp-issuer.pathfinder.gov.bc.ca/)
  > An issuer used to obtain a digital identification credential that is used to authorize access to other services within the PoC.
* [Health Gateway](https://healthbc-issuer.pathfinder.gov.bc.ca/)
  > An issuer used to obtain a personal health number credential that is used to authorize access to other services within the PoC.
* [Essential Services - Organization](https://esr1-issuer.pathfinder.gov.bc.ca/)
  > An issuer used to obtain a business level essential services credential that is used to authorize access to other services within the PoC.
* [Essential Services - Access](https://esr2-issuer.pathfinder.gov.bc.ca/)
  > An issuer used to obtain an essential services access credential that is used to authorize access to other services within the PoC.
* [Med Lab](https://medlab-issuer.pathfinder.gov.bc.ca/)
  > An issuer used to obtain a "lab result" credential that is used to authorize access to other services within the PoC.
* [bcgov/devops-credential-issuer](https://github.com/bcgov/devops-credential-issuer)

### DID

* <a href="https://github.com/decentralized-identity/did-common-typescript" />/decentralized-identity/did-common-typescript</a> - A common bundle of shared code and modules for working with DIDs, DID Documents, and other DID-related activities

### DID-Auth
* [bcgov/did-auth-extension](https://github.com/bcgov/did-auth-extension) - DID Auth browser extension.
* [bcgov/http-did-auth-proxy](https://github.com/bcgov/http-did-auth-proxy) - DID Auth HTTP proxy.
  > This is a DID Auth HTTP proxy that uses [HTTP Signatures](https://www.ietf.org/id/draft-cavage-http-signatures-09.txt) based on [Decentralized Identifiers](https://w3c-ccg.github.io/did-spec/) for authenticated HTTP requests.
* [bcgov/did-auth-relying-party](https://github.com/bcgov/did-auth-relying-party) - DID Auth relying party.
  > This is a DID Auth relying party that can verify incoming DID Auth messages expressed as Verifiable Credentials based on Decentralized Identifiers.


## PSPC-SPAC-buyandsell
**Public Services and Procurement Canada: buyandsell.gc.ca --- Services publics et Approvisionnement Canada : Achatsetventes.gc.ca**

* [PSPC-SPAC-buyandsell/von_tails](https://github.com/PSPC-SPAC-buyandsell/von_tails) - Tails file server for von_anchor issuer and holder-prover anchors
* [PSPC-SPAC-buyandsell/von_base](https://github.com/PSPC-SPAC-buyandsell/von_base)
* [PSPC-SPAC-buyandsell/von_anchor](https://github.com/PSPC-SPAC-buyandsell/von_anchor) - VON anchor classes for interaction with sovrin/indy ledger via indy-sdk
* [PSPC-SPAC-buyandsell/von-image](https://github.com/PSPC-SPAC-buyandsell/von-image) - Standard docker images for building VON components
* [PSPC-SPAC-buyandsell/von-x](https://github.com/PSPC-SPAC-buyandsell/von-x) - VON-X is a Python library enabling rapid deployment of Hyperledger Indy credential issuer, holder, and verifier services, particularly for integration with TheOrgBook.
* [PSPC-SPAC-buyandsell/didauth](https://github.com/PSPC-SPAC-buyandsell/didauth) - DID authentication by way of HTTP Signatures for Hyperledger Indy agents
* [PSPC-SPAC-buyandsell/von_agent](https://github.com/PSPC-SPAC-buyandsell/von_agent) - VON agents using indy-sdk
* [PSPC-SPAC-buyandsell/von_connector](https://github.com/PSPC-SPAC-buyandsell/von_connector) - service wrapper API per agent, via django application
* [PSPC-SPAC-buyandsell/ReferenceVonActuator](https://github.com/PSPC-SPAC-buyandsell/ReferenceVonActuator) - Java implementation of actuator of reference von_connector implementation
* [PSPC-SPAC-buyandsell/von_conx](https://github.com/PSPC-SPAC-buyandsell/von_conx) - Reference implementation (sample) for a VON Connector using tools of VON_X
* [PSPC-SPAC-buyandsell/demo-agent](https://github.com/PSPC-SPAC-buyandsell/demo-agent) - agent and api wrapper code base