---
date: 2020-11-25
title: Augmented Social Network
description: "The Augmented Social Network: Building identity and trust into the next-generation Internet"
excerpt: >
    The Augmented Social Network is a proposal for a "next generation" online community that would strengthen the collaborative nature of the Internet, enhancing its ability to act as a public commons that engages citizens in civil society. The ASN creates an infrastructure for trusted relationships across the entire Internet -- enabling innovation in democratic governance, alternative economics, and social organization of all kinds. The ASN is not a piece of software or a website. Rather, it is an online community system in the public interest that could be implemented in a number of ways, using technology that largely exists today.
layout: single
permalink: literature/augmented-social-network/
canonical_url: 'https://decentralized-id.com/literature/augmented-social-network/'
categories: ["Literature","History"]
tags: ["Planetwork","Augmented Social Network","OASIS","Microsoft"]
header:
  image: /images/asn-header.webp
  caption: "[First Monday](https://firstmonday.org/ojs/index.php/fm/article/view/1068/988)"
  teaser: /images/augmented-social-network-teaser.png
  og_image: /images/augmented-social-network-first-monday.webp
last_modified_at: 2020-11-26
---

## Introduction

**Building identity and trust into the next-generation Internet** 
**by _Ken Jordan_, _Jan Hauser_, and _Steven Foster_.**

> [The ASN white paper](https://web.archive.org/web/20180620134007/http://asn.planetwork.net/asn-archive/AugmentedSocialNetwork.pdf) was presented at the June 2003 Planetwork conference and published in [First Monday](http://www.uic.edu/htbin/cgiwrap/bin/ojs/index.php/fm/article/view/1068/988). There are also [1,000](http://asn.planetwork.net/ASN-1000excerpt.pdf) word and [5,600 word](http://asn.planetwork.net/ASN-5600excerpt.pdf) excerpts from the original 34,000 word white paper.

> The ideas behind the ASN came out of a two year process from 2000 through 2002 facilitated by the [Link Tank](https://www.planetwork.net/link-tank) a group of two dozen professionals in the fields of digital communications, environmental activism, independent media, and socially responsible investment, who met regularly to discuss how a "next generation" Internet could support appropriate responses to the environmental crisis. The group commissioned three of its members, Ken Jordan, Jan Hauser and Steven Foster, to write a white paper that demonstrated the feasibility of the ASN's vision of online community by describing a technical architecture that could achieve that vision.

> The Augmented Social Network is a proposal for a "next generation" online community that would strengthen the collaborative nature of the Internet, enhancing its ability to act as a public commons that engages citizens in civil society. The ASN creates an infrastructure for trusted relationships across the entire Internet -- enabling innovation in democratic governance, alternative economics, and social organization of all kinds. The ASN is not a piece of software or a website. Rather, it is an online community system in the public interest that could be implemented in a number of ways, using technology that largely exists today. The ASN is a system designed to help you find others with whom you share affinities so you can be introduced to them (in an appropriate manner), and then share media with them, or form groups based on shared interests. Importantly, the ASN would facilitate this by connecting people across traditional social, geographic, or technical boundaries. It takes the positive power of the Internet today one step further.

**[ASN Full Text](https://web.archive.org/web/20180620134007/http://asn.planetwork.net/asn-archive/AugmentedSocialNetwork.pdf) • [ASN 1,000 word excerpt](https://web.archive.org/web/20170811014921/http://asn.planetwork.net/ASN-1000excerpt.pdf) • [ASN 5,600 word excerpt](https://web.archive.org/web/20170811014924/http://asn.planetwork.net/ASN-5600excerpt.pdf)**

**The Augmented Social Network**
{% capture notice-4 %}

This foundational piece of literature that paved the way for todays work on Decentralized Identifiers and Verifiable Credentials. As that work comes closer to mass adoption, it may prove valuable to dive deeper into the ideas posed in this paper, since this vision is coming closer to reality every day. 

The only difference between this and the official full-text version from the web-archive, is on-page navigation and I've moved citations to the bottom of whichever section they were found in. - [infominer](https://twitter.com/infominer33)
{% endcapture %}

<div class="notice--success">{{ notice-4 | markdownify }}</div>

**BUILDING IDENTITY AND TRUST INTO THE NEXT-GENERATION INTERNET**

**A REPORT FOR THE LINK TANK**

**_Ken Jordan • Jan Hauser • Steven Foster_**

Presented at the Planetwork conference: 
"**_Networking A Sustainable Future_**" 
in San Francisco on June 6, 2003

[Creative Commons Attribution-NonCommercial-NoDerivs License](https://creativecommons.org/licenses/by-nc-nd/3.0/)

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

## Abstract

Could the next generation of online communications strengthen civil society by better connecting people to others with whom they share affinities, so they can more effectively exchange information and self-organize? Could such a system help to revitalize democracy in the 21st century? When networked personal computing was first developed, engineers concentrated on extending creativity among individuals and enhancing collaboration between a few. They did not much consider what social interaction among millions of Internet users would actually entail. It was thought that the Net's technical architecture need not address the issues of "personal identity" and "trust," since those matters tended to take care of themselves.

This paper proposes the creation of an Augmented Social Network (ASN) that would build identity and trust into the architecture of the Internet, in the public interest, in order to facilitate introductions between people who share affinities or complementary capabilities across social networks. The ASN has three main objectives: 1) To create an Internet-wide system that enables more efficient and effective knowledge sharing between people across institutional, geographic, and social boundaries. 2) To establish a form of persistent online identity that supports the public commons and the values of civil society. 3) To enhance the ability of citizens to form relationships and self-organize around shared interests in communities of practice in order to better engage in the process of democratic governance. In effect, the ASN proposes a form of "online citizenship" for the Information Age.

The ASN is not a piece of software or a website. Rather, it is a model for a next- generation online community that could be implemented in a number of ways, using technology that largely exists today. It is a system that would enhance the power of social networks by using interactive digital media to exploit the transitive nature of trust through the principle of six degrees of connection. As a result, people will be able to inform themselves and self-organize more effectively -- in non-hierarchical, rhizomatic social formations -- leading to more opportunities for engaged citizenship. Part 1 of the paper discusses the concepts behind the ASN, why it is important to pursue such a project today, and the dangers civil society faces if it is not pursued. Part 2 describes a technical architecture for the protocols and software that would support a system of recommendations through trusted third parties across the Internet as a whole. Part 3 offers recommendations for first steps toward achieving the ASN.

The ASN weaves together four distinct technical areas into components of an interdependent system. The four main elements of the ASN are: persistent online identity; interoperability between communities; brokered relationships; and public interest matching technologies. Each of these is discussed in a separate section in detail.

The issue of persistent online identity is examined first through a contrast between the needs of civil society and current initiatives in the commercial sector, the Liberty Alliance Project and Microsoft's .Net identity system, named Passport. The ASN calls for a public interest approach to online identity that enables individuals to express their<sup>2</sup> interests outside contexts determined by commerce. This approach would include a digital profile that has an "affinity reference" that would facilitate connections to trusted third parties.

The section on interoperability between online communities starts with a discussion of Reed's Law, which shows how the value of social networks grows exponentially through interconnectivity. We then discuss how the ASN would apply Reed's Law to online communities of practice in new ways, through the creation of interoperability protocols that will enable individuals to cross more easily between social networks. The ASN would create strategically placed "doors" between online community infrastructures, which today act like "walled castles." Also discussed are the module software applications necessary to extend the functionality of online community infrastructures so they can support ASN activity.

The section on brokered relationships begins by discussing the importance of brokering introductions between people using the ASN, and describes the "introduction protocols" that would facilitate this process. While many ASN introductions would be automated, others of a more sensitive nature will require specialized brokering services that provide customized introductions, appropriate to narrowly defined circumstances. These are discussed, as well as current brokering systems that are developing relevant technology.

The section on public interest matching technologies explains why it is crucial for the civil society sector to participate in the creation of online ontologies and taxonomies that are now shaping the semantic structure of the Internet. Also discussed are the ways that matching technologies enhance online communities, and how the ASN would develop protocols that enable interoperability between online ontological frameworks. The latter would enrich knowledge sharing between social networks by allowing distinct communities to compare "knowledge maps," and easily access diverse viewpoints.

The ASN could be achieved in an incremental manner, with software and protocols developed among a relatively small group of participants, and gradually adopted by larger online community systems as they see fit. The ASN would be built on open standards, shepherded by a not-for-profit initiative that coordinates efforts in the technical areas described above. Aspects of the implementation could be undertaken by for-profit companies that respect these open standards, just as companies today profit from providing email or web pages. But to insure that the ASN meets its public interest objectives, participating organizations would have to agree to abide by the ASN's principles of implementation.


<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

## PART 1: The Future of Online Identity and Trust

### I. The Augmented Social Network

The Internet is a communications platform made from software. This distinguishes it from all previous media, which were determined by the physical characteristics of their materials. Software, by its very nature, is programmable -- which means that the Internet is far more malleable than its predecessors the telegraph, the telephone, print, film, etc. To a significant extent, software can do what we ask of it. It can enable the behaviors we demand from it, as long as we are able to write the necessary code, and that code can be supported by the appropriate hardware.

Online community tools have proven to be extremely effective at connecting people to one another, and helping them to share information. But shouldn't we ask: Can these tools be extended to make them even more powerful, in order to further enhance public discourse? Could they be improved to more effectively advance the values of engaged citizenship and democracy? Could the Internet be better at helping us to:

* Find others with whom we share affinities?
* Share relevant information and media with one another?
* Self-organize, and more easily form alliances to engage constructively with our neighbors, our fellow citizens, and our representatives in government?

In recent decades, globalization has transformed traditional power relationships in society by eroding geographic borders, challenging the sovereignty of the nation-state, and centralizing control of mass media in increasingly few hands. Most of these changes have been driven by commercial interests, with little consideration given to their effect on democracy. The democratic institutions we have were not conceived to work under such conditions, and are straining under new pressures. There is a growing risk that citizens will become alienated from the process of democratic governance, and feel ill equipped to challenge global elites and corporate interests in areas such as the environment, poverty, health, or sustainable development. Might a "next generation Internet" help to reinvigorate democracy by providing a platform that makes it easier for citizens to inform themselves about public policy debates, self-organize, and participate in the process of governance?

Walls have been going up on the Internet. The openness that characterizes the Net is under attack on several fronts. Expansive intellectual property laws, narrowly conceived commercial interests, and governments threatened by digital media's potential to challenge traditional power centers -- each threatens to stifle the Internet's unique ability to connect people and ideas in unprecedented ways. Lawrence Lessig has written insightfully about protecting the Internet as a public commons, a resource shared by all that encourages productive collaboration among its users. Lessig offers a vision of the Internet where walls are kept to a minimum, so that innovative behavior has room to flourish. It is a vision that properly values collaboration, and appreciates the Internet's ability to enable cooperation in ways never before possible.

This report offers a parallel vision, that of a "next generation" online community that would strengthen the collaborative nature of the Internet, enhancing its ability to act as a public commons that involves citizens in civil society. As digital media mature, becoming an increasingly ubiquitous part of 21st century life, they have the potential to be even better at helping people share ideas and organize projects. Of course, as Lessig and others have pointed out, there are many reasons to fear that this potential will not be realized, that short-sighted forces in business and government are conspiring to cripple the Internet, just as the technology is beginning to bloom. For that reason, now is the time to present transformative visions of the Internet, to offer models that suggest how digital media can give birth to networks of trusted association. The "next generation" of online community should be a manifestation of flourishing, innovative democracy that encourages the active participation of its citizenry. Asking for any less would be a betrayal of our highest ideals.

What should online "citizenship" mean in a era of 24/7 connectivity to a ubiquitous information infrastructure? In this new world, you will have an online identity that remains constant, allowing for continuity between your experiences in separate online environments. As in real life, when you go from one virtual social milieu to another your identity will acquire a history. But because this will take place in a digital realm, designed by code and made of data, information will be attached to your identity in ways we are only now beginning to appreciate. Who decides what that capability will be, and most important, whether it contributes or not to civil society? What will your "persistent identity" online say about you, and what shouldn't it say?

In this paper, we make a case for a form of persistent identity that serves civil society. Well conceived, and done in the public interest, persistent identity could enhance interpersonal relationships and social organizing just as powerfully as the PC has extended personal creativity. Much has been written recently about the power of social networks, and the famed "six degrees of separation." Suppose you could go online and make relevant connections with others from whom you are separated by one, two, or three degrees? Suppose that while working on a solar energy project in California, you could use such a system to find an engineer in Shanghai whose experience is directly relevant to your project? Could the Internet be used to establish networks of trust that cross traditional borders? Can the Internet be better at supporting the ability of citizens to self-organize and participate in civil society?

In the early 1960s, the visionary engineer Douglas Engelbart first proposed the idea of a networked personal computer, a machine that would, as he described it, "augment human intellect." He understood that digital technology could enhance the ability of the mind to shape and develop concepts, as well as invite new forms of collaboration. The device that he and his colleagues at Stanford Research Laboratories designed, dubbed the oNLine System (NLS), deliberately expanded on the innate human tendency toward creativity, and aimed to support creativity with the appropriate set of digital tools. The PCs we all use today are the fruits of their effort.

In this paper, we take a similar approach to enhancing person-to-person interaction and group formation through the use of digital communications tools. Just as Engelbart set for his team the goal of "augmenting human intellect," we propose an initiative that will lead to an "Augmented Social Network" (ASN). And just as Engelbart's NLS was guided by the firm belief that people would use these digital tools to, as he put it, "solve the world's problems"^1 (his was a strongly utopian vision), the ASN is designed to support and expand on the fundamental values of an informed and engaged citizenship at the heart of a democratic society. The ASN is not a piece of software or a website; it is not a self-contained application. Rather, it is a model for a "next generation" online community that could be implemented in a variety of ways. The overall objectives are more important than the specific implementation choices (though we do describe an implementation architecture, to show that the ASN is indeed achievable). Unlike Engelbart's NLS, the ASN will not require a decade of intensive R&D at a cutting edge computer science laboratory, because the technology necessary for the ASN already exists, or is being developed. No engineering breakthrough is required. Rather, the challenge facing the ASN is organizational and political, not technological.

The ASN begins with the belief that the contribution to civil society that online community is already making can be dramatically expanded. This premise led us to consider a different way to look at online interpersonal communication. We began by asking: how could new software and standards best support Internet-facilitated, self-propagating, self-organizing communities that are based on trust? This question is particularly relevant in light of recent research into the nature of social networks, and way they encourage collaboration and innovation. Self-organizing groups that come together for reasons other than market forces are increasingly appreciated for their central role in civil society. Could the Internet be improved to help form groups that act in the public interest? Needless to say, this approach differs in crucial ways from the one now being pursued by the commercial sector.

In our lives, each of us inhabits a wide range of distinct, independent social networks. As we move between them, we bring with us our unique interests, our experience, knowledge, and relationships. Each time we go from one social network to another we do not need to restate who we are, what our interests are, or who we know. And we certainly don't leave these aspects of ourselves behind as we cross from one social milieu to the next.

Why is it then, as we go from one online community to another, that our experiences within them are so segregated?

The fact is, given the strengths of computer technology, online communications ought to produce the exact opposite effect. The computer's great power is its ability to store, sort, and distribute information. This information could include aspects of our selves, for example: what we're interested in, who we know, who we trust. Of course, this information could never be comprehensive -- nor should it be, even if it were possible.

But in narrow, tactical areas, such as those relating to our work, or to issues we deeply care about (like rainforests, hunger, or AIDs), information of this kind, within an appropriate system, could be extremely useful in helping us to make relevant connections with others as we go from one online community to the next. (Of course, we would need to feel secure that this information is kept private, and would not be exploited against our
wishes for commercial or other purposes.)

If we are to accept Marshall McLuhan's assertion "the medium is the message," then the software and systems we choose for our communications carry with them, in subtle ways, the values we care to achieve as a society. Before the Internet, we never had the opportunity to engineer forms of social interchange as we do today. In fact, each choice we make about our digital, networked communications infrastructure carries with it political significance -- because it determines how we can connect with one another, and how we might be prevented from connecting. For this reason, it is a concern that the design of the technical infrastructure underlying online communication is increasingly determined by for-profit entities that seek to monetize every aspect of our discourse, and that see communications between people largely as a catalyst for consumer transactions.

Conversely, if we bring a vision of a lively, informed, engaged citizenry to our expectations for online communications, it leads us to ask: What enhancements to the current technical architecture could truly benefit the public interest? If we start with the notion that a person online is a citizen, rather than a consumer, we then wonder: What might be done to improve our online communication tools to make people more effective citizens?

<p><sub id="cite-1">(^1) Douglas Engelbart, "Augmenting Human Intellect," 1 962 ; published in The Augmentation Papers, Bootstrap Institute, 1993.</sub></p>
<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### The ASN has three main objectives:

1. To create an Internet-wide system that enables more efficient and effective knowledge sharing between people across institutional, geographic, and social boundaries.
2. To establish a form of persistent online identity that supports the public commons and the values of civil society.
3. To enhance the ability of citizens to form relationships and self-organize around shared interests in communities of practice in order to better engage in the process of democratic governance.

In this paper we present a model for a next generation online community that can achieve these goals. It is, certainly, an ambitious program. But as we will show, the primary challenges are not technical. Rather, much of the core technology necessary to create the ASN already exists. The question is whether the will and determination can be marshaled to apply tools that currently exist, or that are now emerging, to better serve civil society.

At the same time, we have to consider what will likely happen if a public interest initiative to create the ASN does not take place. Among many of the "digerati" there is a tenacious belief that the Internet will inevitably reach its full potential as an open, democratic public space. Even the dot com crash has done little to challenge the assumption that as the technology keeps evolving, the public interest will somehow be served (as long as governments are willing to police privacy abuses). This attitude ignores the fact that, at key crossroads, choices between competing technical implementations must be made, and that different choices will favor different constituencies. Though public interest and commercial interests have often been aligned during the build out of the Internet infrastructure, this will not always be the case. In fact, divisions between the public good and the business agenda are now multiplying.

Commercial interests are now driving the Internet in a direction that risks leaving important potentials untapped. As mentioned above, legal obstacles, such as intellectual property statues written in another era, threaten to suppress an extraordinary flowering of creativity and information sharing that the Internet already makes possible. The enthusiastic privatization of Internet infrastructure is also an area of concern, potentially leading to a carving up of the Internet into discrete, walled domains, with fees charged at borders. In fact, the cable industry has already begun to establish classifications for different kinds of services, chipping away at the Net's open architecture. Another concern has to do with the issue of online identity management. Two business-based initiatives -- the Passport initiative that is part of Microsoft’s .Net architecture and the Liberty Alliance -- are deliberate efforts to create de-facto standards for personal identity online. Unfortunately, these are primarily focused on how you behave as a consumer, rather than as an independent citizen apart from the commercial arena; their intent is to privatize this information, and then manage it in a way that gives them a share of every financial transaction you make. Current trends are pushing the Internet to become a closed, controlled, commercial space that most resembles a shopping mall. Certainly these initiatives show good business sense, but are they sound public policy?

While the vision is ambitious, the resources needed to achieve the ASN are not
extraordinary. What we propose here is a deliberate effort to create software in the public interest -- a not-for-profit approach to develop software, protocols, and technical infrastructure to benefit civil society. It is notable that, so many years into the "Information Revolution," there has yet to emerge a meaningful support system for this kind of work. We make a case for it here.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

### II. ASN Approach - Designing An Internet-Wide System of Trust

Online person-to-person communication is barely a generation old; only in the last decade or so has it become a true mass medium. Yet the tools most of us use to communicate online, and our expectations of what those tools might enable us to do, have changed little since the first computer-to-computer messages were sent in the 1960s. E-mail, bulletin boards, online chat, and file sharing have long formed the stable core of the interpersonal interaction enabled by computers wired to pass information freely between one another. It is worth recalling that these basic building blocks of online communications were the product of publicly or university funded initiatives; they were not justified by business plans, marketplace analysis, or a projected return on investment.

At the time, engineers concentrated on extending creativity among individuals and enhancing collaboration between a few. While they firmly believed that one day networked personal computers would be used by millions, they didn't much consider what social interaction among millions of Internet users would actually entail. Instead, there was the (perhaps naive) belief that the prevailing ethic of the Internet of that time, based on trust and a commitment to serving the community, was intrinsic to Net culture, and would remain with it as the system grew. It was thought that the Net's technical architecture need not address issues like "identity" or "trust," since those matters tended to take care of themselves.

At first, the social network that emerged from the use of these tools was relatively small. Early users of the Internet could, with some assurance, feel they shared affinities with others they met online. The small size of the community, and the intensity of connections between those who participated, created an environment in which you were encouraged to act responsibly in order to protect your personal reputation. As John Perry Barlow, co-founder of the Electronic Frontier Foundation, put it, "Back then, we knew who everybody was. We knew who to trust."^2 But as the online social network grew from a few hundred to the many millions -- becoming, effectively, many different, overlapping social networks -- the ability to identify affinities and establish trust through the Net withered.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Current Trends in Online Community

Though many of us now take this confused situation for granted, it is, on consideration, a surprising turn of events. Digital technology is widely appreciated for its ability to classify and sort complex information, making knowledge available in increasingly useful ways. Why not apply this capability to support the way people interact in large groups? This discrepancy has been noted by the commercial software industry, and in recent years it began to respond. We are now on the threshold of a new wave of software and standards that could revolutionize the way information is shared and people interact with one another online. New powerful tools -- such as knowledge management systems, online identity programs, digital media distribution, and ubiquitous computing across platforms and devices -- will dramatically extend our ability to access and manipulate information.

But little attention has been paid to how the these software and standards should be designed to best serve the public interest. Instead, this aspect of the "next generation Internet" has been left almost exclusively to the corporate sector, which brings its own intentions and preoccupations to the field of Net-based interactions. And so:

* Questions regarding an individual's online identity are addressed from the perspective of: What will make you a more effective shopper?
* Affinities between individuals online are aggregated and maintained in a way that promotes commercial transactions, rather than enrich the discourse of civil society.
* Systems for extracting meaning from online content, improving the power of searches and enabling relevant links between people and documents, are being designed and applied by the corporate sector, while civil society groups have little access to sophisticated matching technologies to support public interest efforts on issues such as energy, health, or hunger.
* And perhaps most importantly, a myriad of online communities -- both commercial and not-for-profit -- have emerged with little to no interoperability with one another. They exist as separate, isolated islands of discourse, unable to exchange meaningful information, leverage their accumulated knowledge, or connect with other communities that share their concerns.

As the Internet's potential to strengthen the public commons has grown, the public interest sector has done little to insure that the Internet reaches its full potential. Rather, the work of creating online platforms for person-to-person interaction is primarily being driven by the commercial sector, with little public involvement or oversight. But should we expect corporate interests, whose chief motive is profitability, to act in the public interest? In fact, the trends outlined above are pushing the Internet in the exact opposite direction, away from the public commons the Net's pioneers intended for it to be, and toward a form of organization best compared to a shopping mall.

Software and telecommunications companies are now preparing the infrastructure for the "next generation" Internet. Once a new technology is widely enough adopted, it hits a critical mass of usage and effectively becomes a standard. When this tipping point is reached (to use the popular concept written about by Malcolm Gladwell), society is then wedded to that technical implementation -- even if it is not the best available -- and it
becomes impossible to introduce an alternative. This is the way we ended up with the QWERTY keyboard layout, our fax machine standards, and communication standards such as Ethernet.

The technical architectures of communications systems implicitly carry within
themselves political agendas and cultural values. While you cannot predict exactly how people will use communications technology -- unexpected uses continually emerge -- the architecture does set broad parameters for what the system can or cannot do. Before digital media, the difference between one technical architecture or another may not have been too earth shattering. For instance, while the Beta video tape standard was the best on the market, people lived perfectly well for many years with VHS tapes. But with the introduction of digital media, it is a different story. Once the essential qualities of media became programmable, the range of choice we face increased drastically. Interactivity -- the ability to manipulate and change media we use, and to connect with others directly through that media -- has become a consistent option, because with digital media the possibility to include interactivity is always present. If the underlying architecture (the floor plan of the Internet itself) does not allow for certain kinds of interactivity, it simply won't happen. Just as a train can't go where there are no train tracks, certain kinds of online behavior simply cannot take place unless enabled by the proper standards and code. Digital infrastructure does determine behavior to an extraordinary extent. It may not compel behavior, but it enables only select behavior.

Not to over-simplify a complex issue, but the Internet is at a crossroads and has to choose which path to take, what kinds of interactivity to allow. For example, will people on the Net be able to distribute video from their own computers? Will people in Russia have access to U.S. blogs? Will peer-to-peer interactions be permissible, or might they be strictly limited? Decisions are being made today about what behavior will be allowed online tomorrow. No less important than the above examples are the questions: how will each individual be represented online, and how will this effect the way people are able to meet each other and organize on the Net? Will the "next generation" online community serve only commercial interests, or will it also contribute to the public good? If the public interest sector does not act now, these questions will be answered for us, and a tremendous opportunity to reinvigorate democracy may be lost.

<p><sub id="cite-2">(^2) John Perry Barlow in conversation with Ken Jordan, October, 2002.</sub></p>

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### ASN's Democratic Vision

Of course, not everyone is disturbed by the Internet's transformation into a vast commercial space of privately held services, with the standards that underlie it set solely by those companies. There are those who insist that the market can solve most of society's problems, if not all of them, and does that best when left to itself. This attitude, which is partly a stubborn holdover from the dot com boom of the 90s, continues to dominate discussion about the Net today. Let commercial interests develop the Net with a free hand, it is argued, and the public will ultimately benefit. If something new and cool becomes possible online, then people will pay to do it, which means that businesses will be motivated to make that new functionality available.

In his book The Future of Ideas, Lawrence Lessig offers a convincing counter-argument to this market-centric notion. Nearly all the major innovations that made the Internet possible, he points out, were invented for reasons that had little to do with building businesses and getting rich. In fact, one of the great motivators in creating the Internet was pride in contributing to a healthy public commons. Legions of pioneering engineers effectively donated their "intellectual property" to a shared space owned by no single entity, tweaking code, establishing standards, creating a truly unprecedented, global system of trust. This trust came from a simple fact: core components of the Internet are made from software and standards in the public domain, or that are shared freely among engineers. In order for new Net-based products to work, the underlying code has to remain dependable and standardized. But the Internet had no mechanisms for legal enforcement. No one could be put in jail for undermining standards on which new programs were based. So what kept people in line? Nothing more than their commitment to contribute to a communal enterprise. Every time an engineer participated in writing software for a new Net-based project, his actions expressed a profound trust in the system. This implicit trust not only guided the writing of code, but as suggested by John Perry Barlow's comment above, it was reflected in the culture of online communities -- until the commercialization of the Internet in the 90s.

For-profit businesses participated in the making of the Internet, of course. But they did so within a larger "ecosystem" that put the public commons first. In his book, Lessig does a wonderful job of explaining how this happened, how the public commons approach led to a digital platform that is used by for-profit and not-for-profit entities alike. But, as Lessig repeatedly demonstrates, the dominant ethos of the Internet, which supported its relentless innovation and extraordinary growth, was that of a public commons.

Without trusted relationships, civil society comes undone. Francis Fukuyama and others have made a case for the centrality of trust to our economic life, and of course trust is the essential ingredient for democratic governance. But as many commentators have noted, in recent years trust has been in decline in our society. The issue is complex and opinions vary about causes. However, whether it is the barrage of corporate scandals, the low esteem in which most people hold the news media (the source of our public knowledge), or the controversy over vote counting in Florida, symptoms of distrust are rampant.

Commentators dating to Alexis de Tocqueville have credited the importance of community organizations in providing forums where trusted relationships can take shape. Churches, schools, libraries, clubs of all kinds, public meeting spaces -- these local institutions have been the breeding ground for democratic engagement. It is now commonplace to bemoan the widespread erosion of these institutions, which have been hobbled by challenges to traditional spiritual practices, the realities of two-career households, the pressures of an expanding work week, and a steady diet of television. Little attention has been given to the development of new social forms, appropriate to our time, that could reengage citizens with their neighbors and revitalize democracy.

The early Internet is an inspirational model for how a system with the appropriate initial conditions can generate trust among its participants, providing fertile ground for collaboration that leads to extraordinary innovation. Might the next-generation Internet be a locus for trust on a grand scale that could reinvigorate civil society?

The idea behind the ASN is to reestablish the Internet as a platform for trust, as it had originally been. We propose doing this by building trust into the architecture of a next-generation of online community, so that this system of trust can span the entire Internet.

As mentioned above, the original architecture of the Net treated identity and trust a issues that people online would sort out themselves. There was no mechanism put in place to assure you of the identity of others. Back then it wasn't necessary, because the online world was so small, relatively speaking, that people tended to act responsibly in order to protect their reputation.

The intent of the ASN is to support global accountability online, in order to provide a mechanism for introducing people who share affinities or complementary capabilities, enable them to more easily share media among themselves, and allow them to create ad-hoc social networks around specific, narrowly defined topics. In essence, the ASN would apply the power of network computing to the process of group formation -- across the Internet as a whole.

As we discuss later in this report, various flavors of this kind of "introduction" technology are being incorporated into online community infrastructures today. However, each of these communities operates as a "walled castle," separate and distinct from the rest of the Internet. The knowledge and relationships generated inside one community do not travel beyond its borders. The ASN will allow for narrowly defined, carefully targeted interconnections between communities, so that knowledge and relationships can be leveraged across the Internet as a whole. It also proposes a set of tools to be "plugged in" to community infrastructures that will support this enhanced communication across existing social networks.

How would the ASN contribute to a stronger 21st century democracy? First, it calls for treating an individual's online persistent identity as an extension of citizenship; it recognizes that identity in the digital age can and should be configured to support civil society. Secondly, it treats the Internet as a public territory, an open and integrated system that the citizens of the planet hold in common (and which hosts both commercial and not-for-profit initiatives). Third, it enables individuals to more easily meet others outside their existing social networks with whom they can collaborate on public interest issues, as well as share information and media.

Personal empowerment -- the ability to take effective action to shape society -- occurs when an individual can make the link between information and the opportunity to act on that information. You might say that there is an "algorithm for empowerment" that transforms information into knowledge by providing a context for interpretation and action. By participating in social networks, each of us is able to communicate with others in a way that offers the opportunity to take effective action. The ASN extends this opportunity even further by using the Internet to link people across social networks. In particular, it fosters a non-hierarchical distribution of information, and encourages decentralized forms of organization, which can appear in an ad hoc fashion, swarming into existence around a particular objective, and then dissipating when the objective has been accomplished.

In effect, the ASN promises new tools that will support citizen involvement in
governance. Just as citizens in a democracy are guaranteed the right of assembly in a public space -- in order to meet one another, share ideas, organize among themselves, and gather in groups so their voices can be heard -- the ASN proposes a form of public assembly in the virtual realm. But unlike the real world, every form of behavior in digital space has to be enabled by the writing of code. Off-line, public assembly will simply take place if not hampered by restrictions, but online activity has to be deliberately facilitated.

Already de facto standards for online identity and trust are being established. But where is the voice of civil society in these discussions? It is in the areas of identity and trusted relationships that the Internet can most effect the future of democratic governance: by determining under what conditions individuals represent themselves online, and how they are permitted to meet others, share information, and self-organize.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Four Interdependent Elements

Achieving the ASN will require a shift in perspective about both the objectives of online community, and how best to approach its technical framework.

The ASN will not be accomplished through the writing of a single piece of software, or through the proclamations of a standards body, like the World Wide Web Consortium^3. Rather, it will need simultaneous action on a number of different technical fronts. These technical areas have never before been grouped as a single, well-defined set of interlocking topics to be addressed in a coordinated manner. The main challenge is not technical, because no engineering breakthrough is needed to bring the ASN into existence. From an engineering perspective, the challenges are relatively modest. Rather, the greatest challenge is conceptual.

To achieve its objectives, the ASN weaves together four distinct technical areas, and calls for specific development strategies in each. Considerable work is being done in pursuit of key aspects this technical work (though the public interest is not being adequately represented in any of these processes). The ASN approach is unique in that we treat these separate fields as components of an interdependent system. It is based on a coherent
vision that leverages each as part of a greater whole.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### The four main elements of the ASN are:

* **Persistent Identity**. Enabling individuals online to maintain a persistent identity as they move between different Internet communities, and to have personal control over that identity. This identity should be multifarious and ambiguous (as identity is in life itself), capable of reflecting an endless variety of interests, needs, desires, and relationships. It should not be reduced to a recitation of our purchase preferences, since who we are can
not be reduced to what we buy.

* **Interoperability Between Online Communities**. People should be able to cross easily between online communities under narrowly defined circumstances, just as in life we can move from one social network to another. Protocols and standards need to be developed and adopted to enable this interoperability. This interoperability should include the ability to identify and contact others with shared affinities or complementary capabilities, and to share digital media with them, enabling valuable information to pass from one
online community to the next in an efficient manner. To support ASN-type activity, modularized enhancements to the technical infrastructures of separate online communities will need to be developed and adopted.

* **Brokered Relationships**. Using databased information, online brokers (both automated and "live") should be able to facilitate the introduction between people who share affinities and/or complementary capabilities and are seeking to make connections. In this manner, the proverbial "six degrees of separation" can be collapsed to one, two or three degrees -- in a way that is both effective and that respects privacy. Such a system of brokered relationships should also enable people to find information or media that is of interest to them, through the recommendations of trusted third parties.

* **Public Interest Matching Technologies**. The Semantic Web is perhaps the best known effort to create a global "dictionary" of shared terms to facilitate finding information online that is of interest to you. Within the ASN, a public interest initiative around matching technologies, including ontologies and taxonomies, will enable you to find other people with whom you share affinities -- no matter which online communities they belong to. These matching technologies need to be broad and robust enough to include the full range of political discussion about issues of public interest. They should not be confined to commercial or narrowly academic topics; NGOs and other public interest
entities need to be represented in the process that determines these matching technologies.

This technical work could be achieved through many different "flavors" of implementations (most of which, we believe, would be relatively low cost). There is no single way to achieve the ASN. Rather, there are a variety of paths to a "next generation" online community. As technology keeps improving, and the landscape of companies and standards continues to change, any meaningful implementation will require an evaluation of the realistic possibilities available, and opportunistic decisions about which avenue is best to pursue. In this paper we offer recommendations for a series of not-for-profit and commercial initiatives, but with the understanding that these will inevitably evolve with time.

**_The objectives we propose, however, will remain unchanged._**


<p><sub id="cite-3">(^3) Founded in the early 1990s by the inventor of the Web, Tim Berners-Lee, the World Wide Web Consortium (W3C) is a not-for-profit standards body composed of industry and government representatives that develops and approves open technical specifications for the Web.</sub></p>
<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>


### III. The ASN User Experience


Suppose the ASN was in place today. How would it enhance your online experience?
Without delving into technical details, and risking oversimplification, here are some
examples of how it would work:

* Scenario 1. "**Finding Others Who Share Affinities or Complementary Capabilities**"

Jim and Bob are both members of the same online community of people interested in organic farming. Over time they become familiar with one another, and trust each others' opinions. But because they live in different parts of the country, they have never met off line. Because their organic farming online community restricts discussion to narrowly relevant topics, Jim and Bob are unaware that they share a strong interest in solar energy -- even though they both belong to separate online communities that specialize in that subject. So when Jim develops a solar energy project, and is soliciting support for it, he never approaches Bob -- because the mechanism to connect the two, given the current state of online community, does not exist. But with an Augmented Social Network, with its robust system for persistent identity, Jim would be able to search member profiles of the organic farming community, discover Bob's interest in solar energy, and make a solicitation.

In particular, Jim might be working on a project that requires legal advice, and is looking for a lawyer who is expert in zoning. Unfortunately, there are no such lawyers in Jim's solar energy group. But Bob's group does have a zoning specialist, Sara. Using search tools provided through the ASN, once Jim had established a relationship with Bob he would be able to discover that Bob is connected to Sara, a lawyer whose capabilities compliment Jim's work very well. Jim could then approach Sara about the project.

* Scenario 2. "**Links Between Communities with Common Interests**"

On Jim's solar energy online community, a debate is raging about a technical detail regarding solar cells. Among the 50 people who participate in the discussion, no one has the expertise to answer this question. On Bob's solar energy community, however, there is one person who does have this expertise, and in fact has posted this answer online months before. But because the specific vocabulary he used is not what the people in Jim's group anticipated -- it does not closely match their expectations of the answer -- their Web searches do not find this post. With the ASN, there are two different solutions for connecting Jim's group with the answer posted on Bob's community. First, with a public-interest effort to create appropriate matching technologies, including ontologies and taxonomies, a sophisticated schema for the topic of solar energy would be written, so that searches are geared to meaning and do not rely on the use of exact language -- so the original search would have found the post on Bob's community site. But, even more intriguing, with a system of interoperable communities in place a member of Jim's community would have been able to send a query to any or all of the solar energy online communities that exist. Then the expert on Bob's community would have been able to   respond to the question directly, not only resolving their debate, but perhaps providing additional information of great value to the discussion.

* Scenario 3. "**Media Forwarded From Trusted Sources**"

As it happens, Jim's solar energy group is comprised largely of journalists, writers, and theorists, while Bob's group is mostly engineers, mechanics, and sales people in the solar energy business. While Jim's group focuses more on political trends, Bob's group engages in detailed discussions of implementation. A member of Jim's group does an interview with an important solar energy engineer for a small magazine, and decides to make this interview available for free on the Internet. So he sends it to the members of Jim's online group, where it is read and discussed. Given the current state of online community, the chances that member's of Bob's group encounter this interview are completely arbitrary, even though its subject matter relates directly to their interests. But with the ASN in place, because of the trusted relationship between Jim and Bob, the interview would automatically be forwarded from Jim to Bob, and would then automatically be forwarded to interested members of Bob's group. The ASN would facilitate the distribution of media between trusted sources who share affinities (while taking all necessary precautions to protect privacy, and filter out unwanted materials).

* Scenario 4. "**Automated Personal Introductions Across Communities**"

Members of Bob's group are interested in setting up a test implementation of solar cells in a poor South American village, to explore the practicality of a particular technology in that environment. However, they don't have any contacts in South America, and without contacts in the region they are unable to proceed. They don't even know how to begin reaching out to find someone they can trust to partner with. Among Jim's solar group, there is a journalist, Sam, who used to cover energy issues in Buenos Aires and is still in contact with many people in the region. Today, making the connection from Bob's group to the Latin American expert in Jim's group, and then to the appropriate people in Latin America is extremely cumbersome, if it is even possible (without a good deal of work and luck). But with a robust system of online persistent identity, interoperable communities, and brokered relationships, Bob would be able to discover that Jim knows Sam, and an automated system could connect Bob with him. The same system would enable Sam to evaluate Bob's reputation and decide if Bob is someone he can trust in this matter. If so, Sam would then provide an introduction to contacts in Argentina.

* Scenario 5. "**Brokered Personal Introductions Across Communities**"

For Sam, connecting Bob to acquaintances in Buenos Aires has relatively low risk. While Sam hopes that Bob and his group are competent, and handle themselves professionally, if things do not go well it will have little effect on Sam's reputation. However, if Sam knew the mayor of Buenos Aires, and Bob approached Sam specifically because of that highly prized relationship, Sam would probably not be willing to provide an introduction so casually. In certain low risk situations an automated introduction would be sufficient to connect people who have shared affinities or complementary capabilities. But for more sensitive -- and likely valuable -- relationships, a more sophisticated brokering mechanism is necessary to instill trust in the system. Were Bob looking specifically for a contact to the mayor of Buenos Aires, he would first approach a third party broker who could provide an introduction to someone capable of contacting the mayor, such as Sam. In this scenario, Sam would not simply receive an email from Bob, a stranger who had received an automated reference to him via Jim. Rather, Sam would be approached by a brokering service, who would provide a vetted introduction to Bob. Assured by the brokering service that Bob is trustworthy, Sam could then evaluate whether to connect Bob to the mayor.

**Conclusion**: As these scenarios demonstrate, the ASN enhances the way that social networks operate off-line, by making possible more efficient forms of behavior through the use of digital technology. Of course, crucial issues will need to be resolved in order for this system to be effective. We are sober and realistic about these challenges. But, as we will show below, many of the technical issues are being addressed right now. However, most of these are being worked on in the commercial sector, and will lead to implementations that are not necessarily in the public interest. Which is to say: just because the ASN can be achieved does not mean that it will be.

In fact, without a concerted, coordinated public interest effort, this system to support online social networks is much less likely to come about.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Tools To Enhance Citizenship

The ASN automates certain types of interpersonal behavior that the Internet, as it currently stands, does not actively encourage. Of course, the connection-making described in the scenarios above does happen, on occasion. But in those cases serendipity plays a far greater role than science (while the commercial trends now driving the Net will make even this modest level of interconnectivity more difficult). The purpose of the ASN is to turn these kinds of connections into a prominent part of the daily online community experience.

By doing so, the ASN will not only give greater depth and flexibility to the way that individuals who share affinities can meet each other and exchange information. It will also extend the power of online social networks to organize themselves to take actions -- by making it easier for people who have common interests to find one another and share media efficiently among themselves. Democracy is based on the belief that a well- informed populace will self-organize to influence public policy and participate in its own governance. The ASN approach is to enhance online community in a way that will enable people to inform themselves and self-organize more effectively, in order to create more opportunities for engaged citizenship.

**How might the ASN make a difference?** Here are a few examples:

* **Greater Participation in Governance**. While an increasing amount of information has become available to the average person about decisions made by government (through documents published on the Internet, C-SPAN coverage of the legislature, etc.), there has been no corresponding extension of the individual's ability to act on that information in a way that effects policy. In fact, the opposite has occurred. For many people, politics has never been more of a spectator sport. As currently constituted, digital media tools have rarely been able to effect votes in Congress. For example, though email to many Representatives in Washington ran strongly against waging war in Iraq, Congress voted to support the war by a wide margin. The expressed opinion of constituents, in itself, is rarely seen by elected officials as sufficient reason to change or modify a position. Politicians are sensitive, however, to expressed opinions that are connected to the potential for meaningful action -- whether that might be a campaign contribution, or a story in the media, or the mobilizing of voters on election day. E-communications have only been able to influence Washington when they enable constituents to organize among themselves to take collaborative actions, as in the case of MoveOn.org. By enhancing online community so that information is more closely linked to the ability to self- organize, the ASN offers a more powerful platform for coordinated engagement by the people with their government. Smart politicians would seek to use the ASN to strengthen their connection to their constituencies, just as political organizers of all kinds have always used the media forms available to them as best they can. But where pre-digital media was largely about broadcasting information to a passive listener, the ASN extends the Net's interactivity so that participants are more likely to take action based on what they learn -- and organize events that shape the way policy is determined by government.

* **Self-Organizing Around Issues**. There are many millions of people around the world who are concerned about global warming. However, there is now no simple way for these people to become aware of themselves as a distinct group, and organize a specific action to take in unison. With the ASN, and its emphasis on connecting people who share affinities and/or complementary capabilities across different social networks, this group and others like it could self-identify with an ease that had never been possible before. The ASN would allow for large international networks of individuals who share interests to become an important part of the political debate. These issue-specific networks could be a countervailing power that offsets the disproportionate influence of global corporations today.

* **Alternative Economies**. There is a good deal of attention being given to the development of community and complementary currencies, barter economies of various kinds, "green" businesses that follow sustainable environmental practices, and not-for- profit alternatives to standard corporate models. The ASN lends itself particularly well to these initiatives, by making it easier for people to find others who share narrowly defined interests. Moreover, the ASN's ability to distribute relevant information between trusted sources should be particularly intriguing to those who want to exchange goods and services. It might prove to be more effective at attracting attention to a product or service than advertising.

* **Decentralizing Decision-Making**. As globalization has increased everyday access to individuals and materials from around the world, much attention has been given to the creation of non-hierarchical approaches to group formation and decision-making that can leverage these unprecedented relationships and resources in an inclusive, respectful, and just manner. The ASN would be an extremely useful tool to support these efforts toward "good globalization," because it encourages introductions and information sharing across social borders, challenging traditional hierarchies. In addition, it fosters trusted relationships through the Internet, enabling people who share interests to pursue innovative approaches to collective action with others they meet online.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### ASN and The Digital Divide

The Digital Divide is a serious challenge that must be addressed. It is crucial to the future of a just, egalitarian society that the Internet not only be the domain of elites. Some might say that until this imbalance in Internet access is rectified, a project like the ASN should not be a priority. However, were the ASN to be implemented, the argument to address the Digital Divide becomes even more compelling -- because it would be an open acknowledgement of the importance of the Internet to a functioning democracy. The nation would be well served by having access to the Internet considered to be a requirement for every citizen, in order for each person to be well-informed and engaged in their governance.

Attention given to the ASN should not be seen as competitive with Digital Divide efforts.
Rather, the two are highly complementary, and should be pursued in parallel.



<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

## PART 2: The ASN Technical Components

### I. The ASN Architecture


When new functionality is introduced to the Internet, in most cases it comes in the form of a software package, like e-mail or web pages. This software, if it is successful, will then be adopted gradually. Eventually, once enough people have chosen to use the new functionality, it becomes a defacto standard, an additional element that contributes something unique to the Internet's complex infrastructure. At a certain point its use becomes ubiquitous, and it is seen as a core element of the Internet, as email or web pages are today.

We believe that the ASN could be achieved through a similar approach of gradual adoption. But because the ASN is not a single piece of software that can be plugged into existing systems, because it is not simply a new application, it needs to be treated somewhat differently. As mentioned above, the ASN will require a coordinated effort to develop appropriate applications, protocols, and standards in four related but separate technical areas. The technical challenges, in themselves, are not considerable. The development and adoption of the necessary standards poses a greater challenge. But by following a deliberate, focused strategy we believe that the ASN can be brought into existence.

The intention is for the ASN to become the de facto standard for Internet-wide online community interactions-- the functionality described in the scenarios above should be the norm. But it is important to understand that the ASN can be effective if used by only a fraction of the Internet's community members. The ASN can be launched as a sub-set of all online community activity. Then, over time, as it proves itself to be valuable, the ASN's applications, protocols, and standards can be adopted by a growing number of Internet communities.

What follows is a description of the technical architecture for the Augmented Social Network. Think of it as a map of interrelated initiatives necessary to bring the ASN into being. Readers not familiar with the technical vocabulary of persistent identity, online community infrastructures, and matching technologies may find it opaque. We suggest that they skip this section, and go directly to Section II, on Persistent Identity. The remainder of the document following this technical synopsis unpacks its dense language, and discusses the key concepts at greater length.

This plan is not meant to provide the single, definitive blueprint for achieving a system as complex as the ASN. Rather, there are a variety of paths to the ultimate goal. Our purpose here is to be more suggestive than prescriptive. We lay out the essential elements of an interlocking system, and propose ways that they can be made to work together. But digital media is a moving target, continually evolving and improving. Solutions we propose today could be superseded by new innovations over the next 18 months. Moreover, the greatest challenge to creating the ASN is not technical; much of the essential technology for it already exists, or is in development. Rather, the challenge is in adapting this technology to serve the public interest. For that reason, decisions about implementation of the ASN will have to be made in response to the best options available at the time the initiative takes place. The main objectives, however, will remain unchanged.

**The technical strategy**: To enhance the power of social networks by using interactive digital media to exploit the transitive nature of trust through the principle of six degrees of connection. Much has been written about the role played by social networks in civil society, by theorists as diverse as Albert-Laszlo Barabasi, Duncan Watts, Mark Granovetter, Malcom Gladwell, and Manuel Castells. The Augmented Social Network (ASN) seeks to bring a greater level of efficiency and effectiveness to purposeful and goal-oriented social networks by improving the ability of digital communications to support the social networking process. By doing so, the ASN will provide needed tools to enhance non-hierarchical, rhizomatic forms of social organization in the digital era.

This technical program will extend online communities of practice beyond the borders of their existing social networks, by relying on the recommendations and associative capabilities of trusted third parties, in order to add efficiency and effectiveness to: (a) introductions between those who share affinities or have complementary capabilities; (b) the distribution of media among those who share affinities; and (c) the ability of groups that share affinities to quickly self-organize around narrowly defined objectives.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### The essential technical elements of the ASN are as follows:

1. **Persistent Identity**. As federated network identity becomes ubiquitous on the Internet, spearheaded by industry initiatives such as the Liberty Alliance and Passport, civil society organizations will need to articulate a public interest approach to persistent online identity that supports the public commons. As one aspect of a public interest vision of persistent identity, we propose (a) a civil society digital profile that represents an individual's interests and concerns that relate to his or her role as a citizen engaged in forms of democratic governance. One aspect of this civil society approach would be to provide a working model for persistent identity that gives individuals a high level of control over how their profile is used. In particular, the digital profile should include the ability for each individual to (b) express affinities and capabilities, and to list or assist in the discovery of other trusted individuals who share these interests. The purpose of this functionality is to enable automated agents or third party brokers to access this data in a digital profile, through a series of (c) introduction protocols, in order to provide connections between individuals who share affinities or have complementary capabilities. In this way, the ASN is able to introduce those who have shared affinities or complementary capabilities, including those who are members of wholly distinct online communities, based on the recommendations of trusted third parties. These recommendations might either be fully automated, in the case of less valuable or less sensitive relationships, or take place through a brokering service, when privacy, trust, and stakeholdership is of the highest concern.

2. **Enhancements to Online Community Infrastructure**. Some "walled garden" online communities have begun to implement ASN-type functionality within the confines of a single community infrastructure. With the implementation of the ASN, automated ASN interactions will take place across existing online community environments. In order to support this activity, modularized enhancements to the technical infrastructures of separate online communities will need to be developed and adopted. These enhancements are essentially of two types. The first is the writing and adoption of (a) interoperability protocols that will enable communication between the membership management databases of distinct online community infrastructures, so that ASN-related data can flow between separate online communities. The second is the development of modularized applications that enable (b) the pre-processing and post-processing of email communications on online community infrastructures, as well as the ability to compose, address, and tag ASN messages appropriately. These applications would facilitate three types of activity. First, they would enable ASN users to (c) receive specially tagged automated introductions to other with whom they share affinities or have complementary capabilities. These automated introductions may include the name of the person who provided the third party recommendation. Secondly, they would enable (d) automated forwarding of relevant media, based on the expressed affinities of the individual stored as part of his digital profile. Third, they would enable (e) the generation of ad hoc social networks based on expressed affinities and the recommendations or introductions through trusted third parties. These ad hoc social networks would be initiated by an individual sending a request for participation in a narrowly defined project; the message would then be forwarded automatically based on data in digital profiles; the resulting ad hoc community (or swarm) would dissolve with the completion of the stated objective. Online community infrastructures would authenticate the identity of ASN users, and (f) implement reputation mechanisms to enforce accountability for past actions. Reputation mechanisms would reside within the community infrastructure, determined by the context, concerns, and rules appropriate to the needs of each particular community.

3. **Matching Technologies**. For the ASN to be effective, the civil society issues addressed within the system have to be easily identified by searches, with matches made even when exact use of language does not correspond. To facilitate high quality searching which supports online discourse and networking in the public interest, there is a need for an initiative to develop (a) matching technologies for topics relevant to civil society, including public interest ontologies and taxonomies. Focused efforts must be established to insure that ontologies and taxonomies developed with standards such as XML, RDF and topic maps include consideration of those issues relevant to civil society. In addition, the ASN would develop (b) protocols for the interoperability of online ontological frameworks, so that the same set of data could be encountered through multiple perspectives, enabling comparisons of diverse viewpoints, which in itself would lead to new connections between disparate social networks.

4. **Brokering Services**. In instances when personal relationships are highly prized and carefully guarded, though still available through the ASN, an automated introduction system would not be advisable. In these cases, ASN users would engage a third party brokering service to carefully analyze potential affinity or complementary capability matches, and to provide (a) a brokered introduction. These interactions would not necessarily take place only within existing online community infrastructures, but also through the auspices of a brokering service that exists as a separate entity, designed to facilitate these more sensitive introductions. In these special cases, (b) context specific introduction protocols would be developed, allowing each social network to establish the terms through which introductions are made at a highly granular level, perhaps including intermediaries in the process in order to facilitate the initial person-to-person interactions.

Conclusion: These interdependent technical initiatives form a comprehensive vision for a next generation online community that will enhance the capability of social networks to create knowledge, spur innovation, and engage citizens in the governance of their democracy.

Let us now examine each of these initiatives in detail, and see how they relate to the greater whole.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

### II. Persistent Identity

#### Overview: A New Era of Identity

Off-line the question of individual identity is fairly straightforward. It is understood that you are who you represent yourself to be, in most cases, and that your identity can be verified by some form of documentation (which might include, for example, a birth certificate, driver's license, credit card, passport, or letters or recommendation). In most instances you will choose to keep some aspect of your identity private (like a speeding ticket, or a failing grade in school), but you do so in the context of being able to present your "complete self" to others whenever you choose to do so.

On the Internet, however, identity is a far less subtle, and more complicated issue. The Internet, as it is configured today, is poorly suited to support the multifarious nature of identity that we take for granted in daily life. As technologists like to phrase it, the Internet now has a very weak form of identity that is not capable of mirroring how we operate in the real world. Each of us may have one, or several, email addresses, but that specific identification says little about who we are, our interests, or our experience.

The World Wide Web is a super-set of the Internet built on top of the fundamental organizing principal of domain names, which are used in the creation of URLs. Each URL is a "website," or a location on the Internet that individuals can visit by clicking on hyperlinks. Once a URL is established, it essentially becomes the private property of the person or group that is administering it -- the site becomes whatever the site's director chooses for it to be, at a whim.

But while the Web has developed a sophisticated system for the creation of "sites," there has yet to appear a good means to represent each of us as individuals in cyberspace. Every time we visit a new website, we enter as an anonymous person. Then, with our own labor, we create an identity within that specific site, following the rules as they are presented to us (For example: "Please click here to register..."). Once we establish our identity on that website, it effectively becomes the property of the website owner. For this reason, URL-based communities are like walled castles with one-way doors; once you have created an identity on that website, it is only of use on that same website; it can never escape.

The problem presented by identity online is fundamentally a social issue, not a technical one. In the real world, we tend to think of our official "identity" -- that which is documented -- as the minimum verification necessary to confirm that a person is who she says she is. The intention of a free society is to make the threshold for the representation of identity as low as possible. The resistance to identity cards in the United States is an example of the discomfort that most people feel about the prospect of having their personal information captured in a database, where it may be used without their permission. The challenge for a free society is to make the verification of official identity as unobtrusive and "thin" as possible. At the same time, before the Internet, collecting and organizing information pertaining to a "documented identity" required a extensive, well coordinated bureaucracy.

The Internet flips the subject of "documented identity" on its head, because -- in theory -- every action made online can be traced, stored, and analyzed so easily. During the Cold War, East Germany built a hugely expensive and ornate apparatus for just this purpose. The Internet, however, simplifies the task of data retention to such a degree that it becomes possible for profit-making businesses to specialize in the capturing, interpretation and reselling of personal information. Governments, too, have come to appreciate the relative low cost of aggressive data collection and the many efficiencies it could bring to law enforcement. At this point, such far-reaching systems are only beginning to be deployed (in Las Vegas casinos, for instance). But their implementation by marketing executives or the Department of Justice can be curtailed by law and appropriate oversight. Civil libertarians are right to be concerned, especially as norms for the use of personal information on the Internet are still emerging.

It should go without saying that any form of online identity must be designed to prevent, as best as possible, abuses of trust and unwanted violations of privacy rights from occurring. But a progressive vision for online identity should be more than a defensive posture meant to protect individuals from unwelcome incursions on their personal data. Might this same technology be used to strengthen democracy and support a more engaged citizenship? Shouldn't we ask: in an ideal world, what kind of online identity would we want?

It is worth noting that as computing becomes ubiquitous, and surveillance cameras and global positioning devices grow commonplace, the distinction between actions "online" and "off-line" will grow increasingly fuzzy. The tracing and analyzing of an individual's actions will become just as possible in the physical world as on the Internet. The difference between the two, in this regard, will soon be meaningless. Think of the famous scene in Steven Spielberg's movie "Minority Report," when Tom Cruise goes to a clothing store: cameras follow him from the minute he walks in the door; he is identified as a customer in the store's database, and his purchase history is accessed so that the store's automated system can make customized recommendations. Such a digital profile will not only include clothes bought at the brick-and-mortar store itself, but also items ordered online, or at other stores anywhere in the world. This integration of data collected over the Internet with data captured in the real world is already underway. So by addressing the issue of online identity today, we set the stage for a broader discussion about all forms of personal identity, vis a vis society, in the near future.

We are not used to thinking of the representation of our identity as something that we can deliberately design. Never before have we faced the question: How do you build an identity for public use? But the Internet makes this question inevitable. We will all have to consider how we want ourselves to be represented by digital proxies. In the near future, you will build an online identity through an accretion of your actions and expressed affinities -- whether you are aware of it or not. Every online choice you make could potentially contribute to your digital profile.

To sum up, your digital profile is a representation of aspects of your self that accretes over time. In effect, it is a cumulative digital proxy of you that is built from a pre- determined set of components. The emergence of this new kind of identity representation forces us to think differently about "official" identity than we did in pre-digital times. Traditionally, in an open and democratic society, "documented identity" is meant to be as thin as possible. However, in the digital age it will be different. Some form of digital representation of your identity will exist. It will, by its very nature, say more about you than your current forms of identification -- which have relatively thin information.

Many will protest that they do not want any form of online identity to be put in place. But the commercial sector is already creating the infrastructure that will support it, and there is nothing illegal about aggregating the information about what you buy that the system is being based upon. The challenge is not to stop this process, but rather to engage with it and influence it in order to insure that personal identity is implemented in the public interest, so that the system enhances, rather than detracts from, the public commons. The challenge facing progressives and civil libertarians is to acknowledge that we are entering a new era, and to see that with it -- alongside the true danger it presents to individual privacy if abused -- comes an extraordinary potential to improve public life. But first we must accept that "documented identity" will become the converse of what it had been in the past, when the guiding principle was "less is more." Though it is far from a given, online identity could open opportunities for positive forms of behavior, including newly empowered forms of citizenship, that were inconceivable before networked computing.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### From Shopping To Self

Given the commanding role that the market now plays in our society, it should not be surprising that commerce has been the engine driving the development of systems and standards to support online identity for the "next generation Internet." While there are a number of public interest initiatives in this area, they are hampered by a lack of resources, and an inability to forcefully represent the needs of civil society within the bodies that are setting standards for industry. For example, the Internet Engineering Task Force^4 has been developing a system for online contracts that connects identity to reputation in an innovative fashion. Also, projects like XNS.org, One Name, and the Identity Commons are contributing significant intellectual work in this area. However, without industry clout, or a mandate from the public interest sector, their efforts are unable to acquire the momentum necessary to effect industry-only efforts. In the software field, establishing a high adoption rate is critical to a technology's success; it is critical to reach the tipping point where the new piece of software becomes ubiquitous. In part because these worthy efforts are short on resources, and in part because they have not been able to attract significant attention from their natural constituencies (the public interest sphere), they have yet to exert much influence on the shaping of online identity systems. As a result, the problems that online identity is now being designed to solve are the problems of business. The enhancements that online identity might bring to the public commons are not even discussed in forums where decisions are made.

Until recently, online identity came in one of two basic flavors. The first is domain name- specific. Most online communities require the user to register; from this registration a digital profile is created. While in many cases this profile may be no more than an email address, it might also include date of birth, zip code, occupation, and perhaps a credit card number or two. The large online stores have invested considerable resources to create databases that track and analyze purchases; this information then becomes part of each customer's digital profile. If you work for a big company, chances are that you have a digital profile that permits access to certain parts of your employer's intranet, while denying you access to other areas. As an average web surfer, you likely have created dozens, if not hundreds, of digital profiles for yourself on websites all over the Net. As of today, these separate profiles remain unconnected from one another. They do not "speak" to each other and compare notes. But that is about to change.

The second type of online identity is one that is shared between two electronic elements. Usually this is a domain name-related entity such as a website or email handler, and another computer client such as a personal computer or server. Generally this does nothing more than confirm that you are who you ( as versed to a trusted third party) claim to be for the purposes of a particular online transaction. Companies like VeriSign have developed systems that narrowly address the problem of verification: How can a website be certain that the visitor, or shopper, is who she says she is? They provide a "digital certificate" to confirm that the person who initially registered for a service as John Doe is in fact the same John Doe when he clicks to purchase a CD from Amazon or Buy.com. This is a contingent form of identity, one that is dependent on the context in which a transaction takes place. The individual's identity online need not correspond to his identity off-line. In fact, in a famous case, VeriSign issued a digital certificate to an entity called "Microsoft Corporation," enabling it to make online transactions using digital signed certificates that appeared to come from the software giant. Because online identity does not have to correspond to identity in the real world, the necessary verification required to make sure this online "Microsoft Corporation" was the same as Bill Gates' business in Redmond did not take place.

Digital certificates, like those provided by VeriSign, simply confirm that a person has the authority to act on behalf of the person he or she claims to be. They are not designed to provide client websites with any information other than identity verification, and that information is communicated to the client website only when a transaction is taking
place.

In recent years, online businesses began to see the advantages of a persistent identity that could be maintained by an individual as she surfs from site to site. A persistent identity would combine the aggregated information about a person that sophisticated websites currently collect with the verification feature enabled by digital certificates -- so that a user's digital profile could be shared by websites who choose to federate with one another. One of the major initiatives to establish such a form of federated network identity is the Liberty Alliance. In the introduction to the Liberty Alliance specifications document, the objective is succinctly expressed:

> "Today, one's identity on the Internet is fragmented across various identity providers -- employers, Internet portals, various communities, and business services. This fragmentation yields isolated, high-friction, one-to-one customer-to-business relationships and experiences.

> "Federated network identity is the key to reducing this friction and realizing new business taxonomies and opportunities, coupled with new economies of scale. In this new world of federated commerce, a user's online identity, personal profile, personalized online configurations, buying habits and history, and shopping preferences will be administered by the user and securely shared with the organizations of the user's choosing."

There is a strong inclination today to treat online identity as the aggregation of the transactions you make while on the Internet -- most of which are purchases. The implication is: You are what you buy. Of course, the reason for this narrow focus is understandable. Technology and telecommunications companies want to increase online sales, and they see federated network identity as one path to profitability. Of course, it is undeniably true that the products you choose do reflect an aspect of who you are. A digital profile that includes a history of your purchase choices, the web services you use, your medical records, and your travel itineraries would paint a portrait of you that is not without insight. But, at the same time, that portrait would be incomplete. It would leave out many important things about yourself, including the parts you probably value most -- which are likely those most pertinent to participation in the public commons. These aspects would include your political concerns, your relationships with others, and the ways you choose to engage with your community and government.

Because the commercial sector is alone at the table when federated network identity is discussed, the architecture of the system is being tailor made for business, with little regard given to the potential for other uses. Privacy regulations do have a bearing on the development of these standards, and some regulatory agencies have challenged the most egregious examples of aggressive identity data collection. For instance, recently the European Union challenged Microsoft's use of personal data collected through Passport. As a result, Microsoft agreed to give users more choice in determining what data the system collects can be used without permission. But these regulatory measures are reactive, not proactive. They are not expressions of a well-considered, progressive, civil society vision of online identity. Rather, they tend to be projections of 20th century privacy rights into the very different realm of the 21st century.

As suggested above, how we shape online identity now will have broad ramifications for how our identity is represented both online and off-line in the near future. We are setting precedents, and building the underlying infrastructure for the representation of identity in the digital age. What we do today can not help but influence what happens tomorrow. So it is crucial that we ask the right questions, and cut through to the core issues at stake.

How will an individual's digital profile be compiled, and who will control it? Certainly these two questions are central to the issues raised by online identity. In fact, much of the discussion about online identity revolves around how to resolve these questions. But a third question is just as important, though it is seldom raised: What should my online identity say about me?

The challenge is to establish a form of federated network identity that is an appropriate representation of the self, one that is flexible enough to provide a range of "public faces," depending on context. Certainly, information that facilitates commercial transactions should be a part of this identity -- but only part. Defining the full potential of online identity, and pushing for the actualization of that vision as part of the development of the "next generation" Internet, deserves to be a public interest priority.

<p><sub id="cite-4">(^4) The Internet Engineering Task Force (IETF) is the protocol engineering and development arm of the Internet. Though it existed informally for some time, the group was formally established in 1986. It is composed of a large open international community of network designers, operators, vendors, and researchers concerned with the evolution of the Internet architecture and the smooth operation of the Internet</sub></p>
<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Current Efforts in Identity

While there are several independent initiatives focusing on persistent identity, the field is being paced by two large scale efforts that, because of their access to resources and their position in the market, dominate discussion of the issue -- and will likely determine the system everyone else will ultimately use to implement federated network identity. These are the Liberty Alliance, which was mentioned above, Microsoft's .Net identity system, named Passport.^5

Passport was the first out of the box. It was launched in 1999, and had the benefit of the vast database of registered members that Microsoft had accumulated for its various services. Most notably, the HotMail web mail site had many millions of subscribers. Each of those accounts became Passport members, assuming that they chose to take advantage of the system. Today, Passport claims over 200 million members, though it is not clear how many of those people deliberately signed on to be Passport users. In fact, Microsoft has faced significant resistance to Passport from other companies, who cast a suspicious eye on every new project that storms out of Redmond. In the field, there is great concern that online identity -- including each user's personal profile -- might become property of a single corporation. Such centralized control would be a devastating blow to the kind of "circle of trust" that advocates feel is essential to the success of an identity system. Not to mention the red flags it would raise for civil libertarians.

In response to the Microsoft effort, Sun Microsystems rallied together some 30 prominent companies -- including Apache Software Group, NTT DoCoMo, Nokia, VISA, RSA Security, Real Networks, BankAmerica, and Vodaphone -- to form the Liberty Alliance Project. The initiative's stated intention is to develop a system that is similar to Passport in what it offers, but that embraces open standards, interoperability, and a decentralized architecture -- an approach meant to prevent online identity from being controlled by any one entity (whether that entity be a corporation or the government). But while their stated objective is an open standard, there has been no announcement that the eventual standard will be submitted to any governing body, which is the accepted practice for such a process. Moreover, it appears that Liberty is having difficulty agreeing on basic principles of governance regarding these standards. Offering a forum to facilitate the establishment of such principles, and to oversee the implementation of governance, could be an important service for the public interest sector to provide.

In the summer of 2002, Liberty Alliance published version 1.0 of its specifications document. The Liberty Alliance intends to create a system of federation that provides an unique identification to individuals, groups, organizations, applications, and devices -- allowing them to maintain a persistent identity as they move between websites maintained by different, even competing, owners. A key part of this system is the idea of a "single sign-in." When visiting a participating website, you would be asked to authenticate your identity. Through use of a single sign-in, you will be able to maintain the same identity online as you surf from site to site within the federation, and make use of their services, without having to reenter passwords or logins. The verification of your identity, and the profile associated with it, will be maintained by a third party provider. So if you visit eBay, and sign-in to participate in an auction, the eBay site would be assured by a third party identity service that you are who say you are, and some aspect of your digital profile would be provided to eBay. Then, after purchasing that special sugar bowl that struck your fancy, and moving on to WebMD.com, you could enter a discussion area or the e-store immediately, without having to sign. WebMD.com would receive verification of your identity from that same third party identity service, know who you are, and treat you accordingly.

At first it seemed that Passport and Liberty Alliance would go head to head in a brutal battle that would force the Web industry to choose between the two systems -- potentially splitting the Internet into separate, competing identity camps with no interoperability between them. Recently, however, there have been whispers of compromise, and some possibility is emerging that Passport and Liberty might become interoperable at some level. Just as services like Cirrus and Star enable the ATMs of different banks to speak to one another (so you can withdraw cash from an ATM at a bank that is not your own), it appears that something similar might happen on the Internet regarding persistent
identity.

However, because the public interest sector has been largely disengaged from this process, and has not been advocating a strong public commons position, standards are being written that may complicate the implementation of ASN-type functionality in the future. Because of a lack of access to the forums where these decisions are being made, we simply do not know.

Liberty's architecture calls for a variety of identity providers from whom consumers could choose, depending on personal needs and proclivities. Their intent is to create a market for online identity, just there is a market today for web services (like online auction houses, stores, games, specialized information services, newspapers, etc.). It is
conceivable that the public interest sector could collaborate with one or several identity providers to develop digital profiles that reflect the needs of civil society, and not only those of business.

The not-for-profit initiative XNS.org has completed the first iteration of a civil society approach to building identity into the Internet's architecture. This work show great promise. In 2002, XNS.org worked with members of the standards body OASIS^6 to form a technical committee so they could agree on, discuss, and publish a standard for persistent identity and related data-exchange. A specification for the persistent identity standard was published in 2002, and is now making its way through the OASIS approval system. A related specification for data-exchange, using the Security Assertion Markup Language, or SAML, is being developed following the same procedures, with an eye toward ultimate ratification by OASIS. However, as encouraging as this effort appears to be, it is being undertaken with extremely limited resources, with little involvement by the broader civil society community. Without active participation and support from the public interest sector, even if XNS.org can complete the ratification process of a set of core standards (which is likely), it is an open question whether these standards would ever achieve widespread adoption.

<p><sub id="cite-5">(^5) Recently, aspects of Passport have been incorporated into a successor initiative led by Microsoft and IBM, the Web Services Interoperability group, or WS-I.</sub></p>
<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Building Your Online Identity

Underlying this report is the assumption that every individual ought to have the right to control his or her own online identity. You should be able to decide what information about yourself is collected as part of your digital profile, and of that information, who has access to different aspects of it. Certainly, you should be able to read the complete contents of your own digital profile at any time. An online identity should be maintained as a capability that gives the user many forms of control. Without flexible access and control, trust in the system of federated network identity will be minimal.

Both Liberty Alliance and Passport claim that every user will have some measure of control over their digital profile. However, until the final specifications for these systems are published and analyzed, the true degree of user control will remain unknown.. Regardless of their claims, civil libertarians have reason to be suspicious of both Liberty and Passport, because the entire project of federated network identity did not begin within a civil society context, but rather was birthed among businesspeople seeking to maximize profits. To date, online identity is treated the same way as an individual's credit history -- as information that exists as a result of commercial transactions, and so is the proprietary data of the company that captures it. These companies then have the legal right to do with this data as they see fit, including making it available to massive databases that centralize this information for resale. At the same time, your rights as a citizen to access and effect this same information are limited -- as anyone who has ever had to sort out errors in his official credit history can attest.

A digital profile is not treated as the formal extension of the person it represents. But if this crucial data about you is not owned by you, what right do you have to manage its use? At the moment, it seems, this right would have to be granted by the corporations that have captured your data for their own purposes. They may perhaps choose to give you a measure of control over what they do with it. But as long it is their choice to grant you control, rather than your right as a citizen to assert control, the potential for abuse is of grave concern. Just as overly burdensome intellectual property laws threaten to dampen innovation on the Internet, as Lawrence Lessig has described, legacy 20th century laws regarding proprietary information about "customers" could undermine efforts to create a civil society-oriented persistent identity. This could, in turn, strictly limit the forms of trusted relationships that might take place online.

The digital profiles that Internet stores like Amazon have developed of their customers follow a common pattern. Have you ever seen the information about your sales history that Amazon bases its personal recommendations on? Not to suggest that Amazon is a nefarious organization, or that it uses what it learns about customers in an improper way. But you can not gain access to your Amazon profile, even if you wanted to. Nor do you even have the right to ask for it. Today, for most people, this does not pose a problem. Most of us are glad to get Amazon's recommendations (sometimes they are even useful). But a decade hence, as the tools for creating online profiles become far more sophisticated, and stores like Amazon cross-reference their proprietary customer information with that of thousands of other companies, we will be in a very different territory.

Let's take a moment to consider the ways that data about you can be gathered and entered into a digital profile. There are basically three:

First, as with the Amazon example, your online decisions can be traced, entered into a database, and interpreted according to a pre-determined algorithm. This form of automated information gathering, by compiling a database of significant actions, is the most unobtrusive way to build a profile. At the same time, you -- the profile subject -- may be unaware that your actions are being followed and interpreted in this way. It is important that ethical standards are established so that you know when your behavior is being tracked, and when it isn't. Moreover, you should be aware who is tracking your behavior, and what they will do with that information. Most importantly, you should always be given the option to not have your behavior tracked -- this option should be a fundamental right in a free society. By tracked we mean the recording and retention of activity that is retained beyond a certain time limit, transferred to others, and/or retained for future use.

Secondly, you can deliberately enter information about yourself into a digital profile. For example, some online communities have complex registration forms that each new member must fill out in order to participate. Once a member makes clear that she prefers Bob Dylan and Tom Waits to N'Sync and Britiney Spears, she is then led into an online discussion area with others who expressed similar interests. The advantage to profiles compiled like this is that you know exactly what you have chosen to express about yourself, and what you have not. The downside, however, is that filling out forms is cumbersome; most of us prefer to avoid doing it.

The third method is perhaps the most traditional form of information gathering, and least preferred: having others report on your actions without your knowledge. Depending on who controls your digital profile, and how it is used, this method might play a minimal role in federated network identity, or it might be central to it. The more control each individual has over his or her own profile, however, the less likely it is that undesirable or unnecessary reports by others will be a key element. A user should have some ability to determine under what circumstances other people's opinions about his actions might precede him when he enters new situations.

Again, ethical standards need to be agreed to that protect citizens against abuses of this kind, which the technology could easily facilitate.

The identity providers called for in the Liberty Alliance specification would design databases to collect and sort data related to each digital profile, using the data captured in one of these three ways. As Liberty Alliance and Passport documentation suggest, most of their resources will go toward the capture and distribution of information about you that relates to your behavior as a consumer. They give little regard to information that could enhance your behavior as a citizen. (While the specifications might not preclude non-commercial implementations, the resources given to them will be meager at best.) Of course, these systems are not deliberately designed to limit your actions online to consumer-type behavior. There is no conspiracy of nefarious companies who, behind locked doors, scheme to reduce the Internet to nothing more than a vast, digital Wal- Mart. But because no resources are being given to develop parallel systems, or augment the ones under development, civil society online may well be at risk.

Obviously, if participating websites do not request or capture certain kinds of information about you, that data will not become part of your digital profile. As digital profiles become a central component that shape how you engage with the online world -- a trend likely to grow only more pronounced over time -- if your digital profile does not include certain appropriate information about you, it would lead to a reduced ability to fully express yourself on the Internet. If digital profiles are not designed to support the needs of civil society, then it will not be possible to develop web services that might make use of that data -- and an entire territory of potential online behavior will go untapped.

Once we accept that each person should have the right to control the contents of his or her digital profile, we need to ask: What kinds of data should be included as part of it? What information about you could significantly enhance your online interactions? What data in your digital profile would make it possible for you to more easily find relevant media, and to connect with others with whom you share affinities? By its very nature, this type of information may be deeply personal. We are not used to reducing our interests and relationships to a list, to a recitation of topics and names. But if a carefully considered, narrowly focused expression of these aspects of our selves could be designed, and if the distribution of that information could be used to enhance our online experience,
wouldn't we want to use it?

For the moment, let's put aside questions about security and spam, both of which are significant (and are addressed below). Suppose that your digital profile could include data about your special interests -- for example, that you are specialist in solar energy technology. The profile would need to say more than that you are a consumer of solar cells (though you might be), because you have a deeper knowledge than most people who simply purchase a solar energy product. This is where the current plans for federated network identity fall short, because they focus so narrowly on financial transactions. Being a specialist may coincide with being a consumer, but of course the difference between the two is vast.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Affinity and Trusted Third Parties

The foundation for any interoperability between distinct web services (including online communities, e-stores, media distribution sites, etc.) that supports civil society is a form of persistent identity that each citizen can maintain for his or herself in accordance with the rights guaranteed to individuals in a free society. Without this approach to persistent identity, a public interest initiative like the ASN is unthinkable.

But in addition to this fundamental approach to persistent identity, in order to bring about the ASN a specific functionality would have to be part of each digital profile: the ability to express affinities and capabilities, and to list or assist in the discovery of other trusted individuals who share these interests.

What would this entail? As a specialist in solar energy, you would have relationships with others in the solar energy field -- some of whom might also be specialists, some might be curious amateurs, and some who might simply be consumers. Suppose you could enter the affinities you share these people into your digital profile, so that this data added efficiency to how you communicate and share media with them. For instance, if you have a high opinion of the expertise of Jimmy, a solar energy specialist you met at a conference, then your digital profile could express your confidence in Jimmy's opinions on solar issues. This expressed affinity could then automatically solicit information or media from Jimmy on your behalf, when he chooses to reach out to others in the solar energy field (as described earlier in Scenario 3). It would also be possible for Jimmy to provide an introduction between you and a third party, because your confidence in Jimmy gives him the ability to automatically give others direct access to you (as seen in Scenario 4).

Once digital profiles include expressed affinities, the potential for networking through the Internet around common interests becomes significant, because it is a simple technical matter to connect individuals to others based on their shared affinity with a third party. This form of networking could have great reach. Two degrees of separation could provide connections between thousands of people, and three degrees of separation could potentially link over one hundred thousand. In his book Linked: The New Science of Networks, Albert Laszlo-Barabasi discusses at length the contribution that the six degrees principle makes to the effectiveness of social networks. "Each of us is part of a large cluster, the worldwide social net, from which no one is left out," he writes. "We do not know everybody on this globe, but it is guaranteed that there is a path between any two of us in this web of people."^7 Since 1973, when Mark Granovetter's published his groundbreaking study, "The Strength of Weak Ties,"^8 sociologists have examined how trust is conveyed through third parties, enabling individuals to gain access to needed information or resources that support the achievement of specific goals. With the ASN, for the first time the power of network computing across the Internet would be applied deliberately to support this process of social networking in a civil society.

Earlier we defined the technical strategy of the ASN this way: To enhance the power of social networks by using interactive digital media to exploit the transitive nature of trust through the principle of six degrees of connection. The purpose of the ASN is to enable connections based on shared affinities and compatible capabilities to occur across the borders of distinct social networks. The ASN will improve the efficiency and effectiveness of citizens to share information and self-organize through the tactical use of digital media.

Such a system is based on the principle of "trusted third parties." Here is a simple example of how "trusted third parties" will work online: Both Bob and Nancy know Alice. While Bob and Nancy do not know each other, they both express an affinity with Alice about a particular subject -- safe energy. That affinity is entered deliberately as part of their digital profiles. This expressed affinity confers the capability to Bob to conduct automated transactions with Nancy (who he does not know) about safe energy related issues. In practice, each of the "trusted third party" entities could be larger aggregates of individuals, such as organizations or businesses. Or they could be software agents, which implement various contracts and services. In an open, networked digital environment, like the Internet, the capabilities of this kind of transaction emerge as important as the transactions among the users become important.

Users of the ASN would need to maintain a list on their digital profile of those with whom they share affinities or complementary capabilities. This "affinity reference" might be entered into the digital profile directly by the user, or it could be automatically deduced by software that interprets behavior (for example, exchanging email with the same person five times a day about a particular topic might automatically generate an "affinity reference"). There are many ways such "affinity references" could be collected by an identity provider, depending on the kinds of web services that emerge to make use of them. Suffice it to say that, as long as the user can determine the specific content related to affinities kept in his or her digital profile, and can decide when and how that data is to be used, the potential of digital media to enhance trusted interactions between third parties is tremendous.

The "affinity reference" would be designed so that automated agents or third party brokers are able to access this data, allowing them to provide relevant introductions between individuals, or to facilitate the forwarding of media or messages based on expressed affinities. In effect, the system would allow for expressions of trust between participants to be transferred to third parties. But trust between people is a subtle, complicated form of interaction. There is no simple way to characterize trust relationships, no one-size-fits-all system that can adequately represent in the digital realm the variety of trust relationships that occur between people in the real world.

The type of "trust" referred to here is not meant to represent all the nuances of trust in real life. Rather, the ASN requires that the "affinity reference" only refer to a particular person in regard to a narrowly defined topic. Using the Alice-Bob-Nancy example above, the " affinity reference" between them might only apply to the issue of safe energy -- and to nothing else. While digital profiles could enable the user to include "affinity references" about many people in a multitude of situations, most likely they would be used only for purposes with tightly constrained boundaries. The technology requires such constraints in order for it to be a practical tool.

Still, it is important that the ASN approximate a range of circumstances in which trust between people is articulated and extended. To do so, the ASN will need to offer several different kinds of affinity-based interactions. Some might be fully automated, as in the case of less valuable or less sensitive relationships. But in instances when personal relationships are highly prized and carefully guarded, though still available through the ASN, an automated introduction system would not be advisable. In these cases, ASN users would engage a third party brokering service to carefully analyze potential affinity or complementary capability matches, and provide a brokered introduction. (Brokering services are discussed below, in Section V.) To facilitate this variety of interactions, a set of "introduction protocols" will need to be written and adopted.

Trusted transactions within an ASN system would range widely in value, which means that the system has to be built to accommodate a wide range of risk. Certainly, the technology underlying the system must have the confidence of its users. It needs to be robust enough to scale up in order to meet the demands that greater risk requires from it. While this challenge can be addressed in many ways, our preference is to use a distributed and decentralized architecture that decreases the possibility of a technical failure at a centralized location -- and so increases the reliability, robustness, and trustworthiness of the system overall. In addition, the system's technical architecture ought to be designed in a manner that allows for independent verifiability and certification at all levels. This means that all the technical services that participate in making the system function are able to verify that it meets its design goals. For that reason, the design should be simple, because complex systems, with millions of lines of code, are difficult to read -- which effectively makes verification impossible.

<p><sub id="cite-6">(^6) OASIS is a not-for-profit, global consortium that drives the development, convergence and adoption of e-business standards.  For more, go to <a href="http://www.oasis-open.org">http://www.oasis-open.org</a> (May 5, 2003).</sub><br>
<sub id="cite-7">(^7) Albert-Laszlo Barabasi, Linked: The New Science of Networks, Perseus Publishing (Cambridge, Ma., 2002), p.18.</sub><br>
<sub id="cite-8">(^8) Mark S. Granovetter, "The Strength of Weak Ties," American Journal of Sociology 78, (1973), 1360-1390.</sub></p>

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Security

After reading the previous section, you may be thinking: "I'd never enter my personal relationships and the level of trust I have in them into an online database, because it could get hacked. How can I risk putting that kind of information into a system that isn't 100 percent secure? The Internet is famously risky when it comes to keeping information private."

The security of information online is one of the hot topics of the digital communications field. Magazines are devoted to it, library shelves are packed with books about it, debates rage on the web about the relative worth of competing approaches, and large sums of money are flowing from corporate and government coffers to pay for technology that promises to make their data more secure. But despite all the effort, no foolproof form of security has yet emerged. And it likely never will.

Nonetheless, the digitization of highly sensitive data continues apace. Why? Because these major institutions have come to feel that their data, while not 100 percent protected, is safe within an acceptable level of risk. Just as no bank can ever guarantee that it will never be robbed, and no business person can be certain that every signed contract will be fulfilled, it is an acknowledged fact of life that servers might on occasion be breached, that data could conceivably fall into the wrong hands. But the level of risk is no greater in the digital realm than it is the material world -- where you take a risk each time you hand your credit card to a waiter. As long as precautions are followed, and resources are put toward the protection of data, in most cases illegal activity can be prevented.

The wheels are already in motion to digitize some of the most sensitive personal information imaginable -- including your finances, work history, and health care records. The security protecting these databases may not be infallible, but it is pretty good. "Pretty Good Privacy," in fact, is the name of one of leading encryption standards. The notion behind it is that, as long as you can be assured that your information is being reasonably protected, you should be able to feel confidence in the system.

Certainly, everyone needs to maintain a vigilance regarding the security of their personal data. This will be one of the touchstone civil rights issues of the digital era -- who gets to know what about you, and how is it protected. At the same time, as mentioned above, it does little good for progressives to respond to this situation by affecting a Luddite position, using a 20th century model for "official identity" ("less is more") as the guide for policy in the 21st. Today's Internet security is reliable enough to support a working system of federated network identity. Online identity will become an ubiquitous part of daily life. The greatest danger to civil society is not that the data associated with digital profiles is open to theft and illegal activity, but rather the real possibility that a system of federated network identity that erodes civil liberties and the public commons comes into being -- while following the letter of the law.

That is why it is so important to put forward a progressive vision of online identity, and to promote projects that strengthen the public commons on the Internet, like the Augmented Social Network. Without that positive, forward thinking agenda, when it comes to the Internet, civil society groups are left with little else to pursue than defensive, rearguard actions.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Persistent Identity and the ASN

A civil society approach to persistent identity is a cornerstone of the Augmented Social Network project. Without it, the ASN is hard to imagine -- because for the ASN to work, you must be able to find other people online based on their expressed interests and affinities, and to choose your level of engagement with them based on their reputation, which means that a record musts be kept of their relevant past actions. The ASN requires a technical system to provide this functionality.

In life, we enter into social networks either because we are attracted to the ideas and activities at the center of a particular group, or we are introduced into the group by someone we know. The intent of the ASN is to bring an appropriate level of automation to this process, to make it more efficient and effective -- particularly when it comes to narrowly defined interests and projects. Today, many of us feel that the mainstream media is poorly equipped to provide us with the news and information we need to be effective citizens. At the same time, while we cognitively grasp the effect that globalization has on our lives, and the increasing interconnectedness between people from all parts of the globe, our tools for acting as citizens on this understanding are poor. Though the business world has created exceptional tools for acting globally (so that a decision made in a Cleveland boardroom can redirect activity at a Bangalore factory in a micro-second -- or vise versa), for individuals it is much more difficult to make efficient cross-border connections and to organize. The efficiencies in communications that digital technology have brought to large institutions should also be made available to citizens participating in the public commons. A civil society approach to federated network identity would provide the underpinnings necessary for the kinds of interactions that would strengthen the public commons. The ASN is one system that would take advantage of the civil society data in a digital profile -- but there could conceivably be many others.

As mentioned above, the essential technical components of such a system are already being designed and implemented to pave the way for federated network identity. The latest indications suggest that, broadly speaking, the Liberty Alliance and Passport initiatives could support the kind of persistent identity required by the ASN -- though there is no guarantee of this if civil society organizations are not represented at the table when key issues about technical architecture are being decided. Certainly, the specific needs of the public commons are not being written into the specifications of federated network identity. These specifications do not seem to disallow non-commercial requirements. But without a dedicated public interest effort to address this issue, we cannot be sure what the final draft of the specifications will call for.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

### III. Enhancements To Online Community Infrastructure

#### Creating Value Through The Network Effect

Social networks have become a hot topic in the communications field. Theorists as diverse as Albert-Laszlo Barabasi, Duncan Watts, Mark Granovetter, Malcolm Gladwell, Steven Johnson, and Manuel Castells have explored the emergent properties of group behavior in social networks. Many of them use the popular notion of "six degrees of separation" to demonstrate the ability of loose, informal networks to catalyze complex forms of social organization. The ASN is an attempt to deliberately apply the six degrees principle to online relationships, across traditional borders, in the public interest.

In his book Smart Mobs: The Next Social Revolution, Howard Rheingold describes the potential of digital communications to catalyze new forms of cooperation:

> "The most profoundly transformative potential of connecting human social proclivities to the efficiency of information technologies is the chance to do new things together, the potential for cooperating on scales and in ways never before possible. Limiting factors in the growth of human social arrangements have always been overcome by the ability to cooperate on larger scales: the emergence of agriculture ten thousand years ago, the origin of the alphabet five thousand years ago, the development of science, the nation-state, the telegraph in recent centuries, did more than accelerate the pace of life and make it possible for the human population to expand. These cultural levers also enlarged the scale of cooperation, radically altering the way people live."^9

Rheingold raises the possibility that mobile and pervasive digital media might lead to "breakouts of cooperation [that] could expand liberty."^10 But can the Internet really be effective in this way? Lessons from recent years suggest that it could.

Peer-to-peer networks, like Napster (for file sharing) and IGC (for instant messaging), gave us glimpses of how direct communication between members of an online community expands connection-making and information sharing. These are examples of a phenomenon that has come to be known at the "Network Effect." Robert Metcalfe, who led the team that invented Ethernet, noticed the Network Effect in the early days of wired computing, and distilled this observation into "Metcalfe's Law"^11 : "The total value of a network where each node can reach every other node grows with the square of the number of nodes."^12 As Rheingold explains:

> "If you have two nodes, each with a value of one unit, the value of joining them is four units. Four interconnected nodes, each still worth one unit, is worth sixteen units when networked, and one hundred nodes is worth one hundred times one hundred, or ten thousand. When value increases exponentially more quickly than the total number of nodes, the mathematical consequence translates into economic leverage: Connecting two networks creates far more value than the sum of their values as independent networks."^13

For that reason, as community expert David Reed has written, "There is an enormous incentive to find ways to interconnect networks, since the members of each network can access a much larger set of potential transaction partners."^14 In his paper "That Sneaky Exponential -- Beyond Metcalfe's Law to the Power of Community Building," Reed explains, "While many kinds of value grow proportionally to network size and some grow proportionally to the square of network size, I've discovered that some network structures create total value that can scale even faster than that. Networks that support the construction of communicating groups create value that scales exponentially with network size, i.e. much more rapidly than Metcalfe's square law." As Reed observed, connectivity between computers allowed for the creation of simple networks, but that online community tools enable the formation of networks that self-organize into groups. These Group Forming Networks (GFNs), as he calls them, are social networks that coalesce around common interests, issues, or goals. They represent an even greater value created by interconnectivity. "What I found," Reed wrote, "... is that GFN's create a new kind of connectivity value that scales exponentially..." This exponential growth in value created by the interconnection of social networks is known as Reed's Law.^15

Reed's Law describes how connectivity and various network properties create new, and previously unknown, types of value. It also offers a way to compare the value of GFNs to that of pre-digital communication network forms, such as radio and TV networks. This comparison offers a clear understanding of the mathematical basis of these networking technologies in order to evaluate their potential effects.

The table and graphics below illustrate the extended reach of Group Forming Networks. The table denotes the various classes of networks and gives examples. The graph illustrates how value increases as the number of members increases.

**_Figure 1_**

| Law: | Sarnof | Metcalfe | GFN (Reed) | 
| --- | --- | --- | --- |
| Optional | Tune In | Connect Peers | Join/Create Groups |
| Transactions | Broadcast | | |
| Examples | OnSale Remote Access | Yahoo! Classifieds, EMail | eBay Chat Rooms |
| Value of N member net | N | N^2 | 2^N | 
| Combined Value of N,M member nets | N + M | N2 + M2 + 2NM | 2N x 2M |

The value increase of the three network types above is graphed below in figure 2.

![](https://i.imgur.com/g2KSREH.png)

Note that the previous standard for the Network Effect, Metcalfe’s Law in yellow, appears almost flat when graphed in proportion to GFN’s. The value increase of this new Network Effect dwarfs the pervious standard.

Reed's observation about the way Group Forming Networks generate value parallels the conclusions reached by artificial life researcher Norman Johnson, who developed computer models to study "collective problem solving."^16 Johnson and his colleagues examined how networked communications improve collaboration among groups engaged in a task. Using a maze as a test case, they found that the greater the range of appropriate knowledge available to the problem solvers, the more effective their work became. They identified patterns of collective behavior that emerged in the act of sharing information while problem solving. And they demonstrated the importance of having a diverse range of information sources available when addressing complex tasks. It may not be surprising that diversity plays a key role in knowledge creation. Most of us know that from our own experience. But only recently has that understanding been applied to the way groups work together through digital media.

How might our online community tools be made even more effective at enabling collaboration? How might society benefit from improvements to the Internet that make interconnections between social networks even more plentiful?


<p><sub id="cite-9">(^9) Howard Rheingold, Smart Mobs: The Next Social Revolution, Perseus Publishing (New York, 2003), p.11 4</sub><br>
<sub id="cite-10">(^10) ibid, p.114</sub><br>
<sub id="cite-11">(^11) Among engineers, Metcalfe's Law is sometimes referred to as the "polynomial function of degree 2."</sub><br>
<sub id="cite-12">(^12) ibid, p.59</sub><br>
<sub id="cite-13">(^13) ibid, p.59</sub><br>
<sub id="cite-14">(^14) David Reed, "<a href="https://www.immagic.com/eLibrary/ARCHIVES/GENERAL/GENREF/C030200R.pdf">That Sneaky Exponential -- Beyond Metcalfe's Law to the Power of Community Building</a>"</sub><br>
<sub id="cite-15">(^15) Sometimes Reed's Law is also referred to as the " exponential function".</sub><br>
<sub id="cite-16">(^16) Johnson, Rasmussen, and Kantor, "The Symbiotic Intelligence Project" and N. Johnson, "Collective Problem Solving"</sub></p>

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Extending Communities of Practice

Most of us participate in several online social networks at once -- some related to work, others to interests or hobbies, and still others based on personal relationships, like school or family ties. For instance, at your job you may have access to a company intranet that coordinates information sharing between offices in different cities. At home you might use iVillages' bulletin boards to discuss health issues or parenting. You may also be on several email lists about topics of interest, ranging from favorite films to safe energy, and regularly post messages to these lists. Each of these is a separate social network that operates independently of the others -- you might be the only common link between them.

Of the many kinds of social networks that exist online, the Augmented Social Network is concerned with only one: communities of practice. Unlike other forms of group engagement, communities of practice are organized around the achievement of specific objectives. As the social theorist Etienne Wenger defines them, communities of practice "are focused on a domain of knowledge and over time accumulate expertise in this domain. They develop their shared practice by interacting around problems, solutions, and insights, and building a common store of knowledge."^17 He goes on to explain:

> "The term 'communities of practice' is of relatively recent coinage, but the phenomenon it refers to is age-old and social scientists have talked about it under various guises. In a nutshell... [it] is a group of people who share an interest in a domain of human endeavor and engage in a process of collective learning that creates bonds between them: a tribe, a garage band, a group of engineers working on similar problems.

> "Not everything called a community is a community of practice. A neighborhood, for instance, is often called a community, but is usually not a community of practice."

Wenger has described how digital media extend the effectiveness of communities of practice, making communication more efficient within a group, improving its ability to self-organize, address problems, and support innovation. These observations parallel those of David Reed, who has noted how online tools increase the reach of social networks. These insights inform the design of a new wave of corporate intranets, multimillion dollar web-based communications systems built by IBM and Microsoft, as well as other smaller software companies. These intranets, sometimes referred to as "knowledge management systems," treat email, bulletin boards, file sharing, content databases, membership profiles, and powerful search tools as elements of an integrated system that encourages productive collaboration. Such high-powered online community infrastructures are being widely adopted in the commercial sector because of their ability to improve the efficiency and effectiveness of group activity, particularly between team partners in different cities, or for employees assigned to separate divisions that rarely communicate.

Cynthia Typaldos has diagramed a set of "12 Principles of Civilization" relevant to purposeful online communities from her own experience creating communities of practice online. She suggests that these principles should form the basis of a kind of "community operating system." This would not be a technical operating system, in the sense of NT or Unix, but a conceptual operating system that would guide the choice of applications and protocols used by a social network for their online communications. Community infrastructures can vary widely, from simple listsevs for email lists, to more sophisticated websites like Slashdot, to high end corporate intranets. It is worth considering Typaldos' diagram below to appreciate the range of social interactions that take place within a community of practice, each of which requires its own standards of behavior, and technical applications to support that behavior. It is possible that, in time, the components of community infrastructures will become increasingly standardized, and that the more high end systems will be built from modular components that are commonly available. Today, however, that is not the case. In fact, the differences in the technical elements underlying online communities can be quite great.

<p><sub id="cite-17">(^17) Etienne Wenger, "Supporting Communities of Practice: A Survey of Community-Oriented Technologies," March, 2001</sub></p>
<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Cynthia Typaldos' "12 Principles of Civilization"

![](https://i.imgur.com/lNvVMvn.png)

Typically the design of online community infrastructure is that of a "walled castle;" that is, the information and relationships cultivated in each are not meant to be shared outside the community walls. Little to no effort is made to harness the valuable knowledge created by these online community systems so they can be made available to other communities. To the contrary, the tremendous value generated by these systems is trapped inside each. In many cases, that value is regarded as proprietary, and is jealously guarded. This is understandable, at first blush, because each successful online social network devotes great effort toward the cultivation of its own culture, while also using the distinction of its membership to attract other participants. There is sometimes an assumption that anything less than a "walled castle" approach would dissipate the community's unique qualities, undermining the efforts of community organizers to shape a protected space for discourse.

But consider how the discourse of a particular online community could be enhanced by having selective access to expertise cultivated by other social networks. A process that allowed for the strategic sharing of targeted information and relationships across the borders of these "walled castles" could greatly enhance the value of participating in online community for all community members. In the early days of the Web, there was a widespread belief among commercial sites that it was a mistake to provide links to other websites, and that every effort should be made to keep visitors from going to other web content sources. However, they discovered in time that the most popular and successful websites were the ones that offered the most useful links to third party sources. Now strategic, narrowly targeted links between "competitor" sites are commonplace. The ASN would similarly make the interoperability between distinct online communities strategic and narrowly targeted. The functionality would be designed to extend the activities of communities of practice so that they could selectively make contacts across the borders of online communities, following the principle of six degrees of connection.

The ASN would bring the core online mechanisms that support communities of practice to the Internet as a whole, so that citizens can more effectively collaborate on civil society issues. It identifies these technical components, most of which have been developed as aspects of the infrastructure of "walled castle" online communities, and extrapolates from them global standards and practices to be adopted across the Internet, in a non-proprietary fashion. It would enable individuals to discover others outside of their social network with whom they share affinities or have compatible capabilities, allowing them to exchange relevant information and media among themselves, and to self-organize around specific subjects and initiatives. Importantly, it would achieve these objectives through the adoption of global standards that would, in themselves, bring a useful uniformity to the online introduction of strangers from different social networks. These protocols would, in effect, establish a standard "global handshake" that would be immediately recognizable to people from a wide range of cultural backgrounds. It would ease the awkwardness that comes with meeting new people, especially those from a different social background, or an unfamiliar part of the world.

Could this be done without threatening the interests of existing online communities, but in fact enhance their efficiency and value? The ASN should be embraced by existing online communities, because its intent is not to replace them, but rather to offer additional functionality that enhances their value. Just as commercial content sites came to appreciate the additional traffic that targeted links to "competitors" brought them, online communities will be glad to see the added traffic that comes with tactical interconnection between social networks. The ASN will augment current systems with new capabilities that expands their effectiveness, in the public interest.

Most importantly, the ASN will not "break down the walls" between online social networks to create a single, global online community. Rather, the ASN calls for strategically placed doors that allow people and information to pass from one distinct online social network to another under certain, limited circumstances. Using advanced matching technologies (described below, in Section IV), the ASN will be able to pinpoint shared affinities and complementary capabilities between people to a highly granular degree. It would only be used to achieve specific objectives that advance the work of communities of practice; it would not lend itself to other, less pragmatic uses. The objective is not a single, massive social network, but a multitude of interlocking independent communities. Such a system would not threaten the cohesive nature of a thriving online social network; rather, it should enhance it.

There are some who say that making a single, borderless online community is a utopian ideal worth pursuing. However, aside from the obstacles to adoption this would create by alienating existing online communities, the notion of a single online community may well run counter to human nature. In his article "Communities, Audiences, and Scale,"^18 Clay Shirky suggests that a threshold for online community size exists that, once passed, transforms an active, engaged community into a passive, traditional audience -- that is, a group of people who only receive information rather than interact with each other. "Members of a community are connected to one another, not just to some central outlet -- a many-to-many pattern," he writes. "As a result," he continues, "communities have strong upper limits to size, while audiences can grow arbitrarily large. Put another way, the larger the group held together by communication grows, the more it must become like an audience -- largely disconnected and held together by communication traveling from center to the edge -- because increasing the number of people in a group weakens
communal connection."^19

Shirky cites the work of primatologist Robin Dunbar, who "argues that humans are adapted for social group sizes of around 150 or less, a size that shows up in a number of traditional societies, as well as in present day groups such as the Hutterite religious communities. Dunbar argues that the human brain is optimized for keeping track of social relationships in groups smaller than 150, but not larger."^20

It is questionable whether the 35 million subscribers to AOL think of themselves as belonging to a single online community -- though there are many thousands of distinct, if often overlapping, communities (or social networks) that have organized themselves on the AOL platform. Suffice it to say that, while it is difficult (if not impossible) to try to pin point the size of the "ideal" community, an awareness that communities are not infinitely expandable bears directly on how we propose to execute the ASN.

<p><sub id="cite-18">(^18) Clay Shirky, "Communities, Audiences, and Scale," April 6, 2002 <a href="http://web.archive.org/web/20120217080908/http://shirky.com/writings/community_scale.html">http://shirky.com/writings/community_scale.html</a> (May 14, 2003)</sub><br>
<sub id="cite-19">(^19) ibid.</sub><br>
<sub id="cite-20">(^20) ibid. The original reference is to Robin Dunbar's Grooming, Gossip, and the Evolution of Language (ISBN 0674363361).</sub></p>

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### ASN Community Functionality

Communities of practice benefit from digital media in a number of ways. Most obviously, they make use of the standard set of communication tools that form the basis of most online communities: email, forums, chat, file sharing, and -- in the case of advanced online systems -- video conferencing and collaborative document creation. They also can take advantage of membership management systems, which include member pages with biographical information. While there is a great deal of variability between specific online community infrastructures, this functionality has become a kind of standard tool kit, and most communities pick and choose elements from this kit. The ASN treats this functionality as a given, and suggests few changes to it.

Communities of practice could be supported by new types of online functionality just beginning to be adopted. These could be broadly regarded as matching technologies, on the one hand, and introduction technologies, on the other.

A number of "walled castle" online communities already use matching technologies to extend the effectiveness of communities of practice within the confines of a single community infrastructure. For example, on an advanced corporate intranet, search tools using matching technologies might discover that three employees from different divisions have raised the same question about a particular project. This allows them to contact one another so they can collaborative on an issue each had previously addressed alone.

Some of these community systems are still in development, and not all have been publicly launched. But, significantly, a number of them intend to do more than simply provide an enhanced searching capability. These next-generation community systems could make introductions between members who have been identified by matching technologies as having common affinities and complementary capabilities. They could do this by analyzing board postings, email messages, shared documents, online biographies, and other material maintained as part of the online community's database. The notion that the expression of your interests should lead to useful introductions or access to relevant information is likely to become commonplace in the coming years. But, to date, the technology developed to support this activity is limited to each distinct online community, divorced from the rest.

The ASN would extend matching and introduction technologies to communities of practice across the borders of existing online community infrastructures, in order to support civil society initiatives.

As discussed in the previous section, introductions in the ASN would take place in one of two ways: they would either be automated or brokered. Third party brokering services would likely be the preferred option among ASN users when the personal relationships involved are highly prized and carefully guarded. We address brokering services in the next section of this paper.

For less valuable or less sensitive relationships, the ASN interactions would be automated, and they would take place on the infrastructures of existing online communities. For example, if both Salon.com and Utne.com participate in the ASN, an automated introduction would be possible between a Salon member and an Utne member who share an affinity through their relationship with a trusted third party. The Salon and Utne infrastructures would facilitate the automated ASN interaction.

To support this activity, modularized enhancements to the technical infrastructures of online communities will need to be developed and adopted. These enhancements are essentially of two types: (1) the writing and adoption of interoperability protocols that enable communication between the membership management databases of distinct online communities, and (2) the development of modularized applications for the pre-processing and post-processing of email communications.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Interoperability Between Communities

Today, your online profile and activity on Utne.com has no way of effecting your online profile and activity on iVillage.com. Because each online community is conceived and built as a "walled castle," no opportunity is provided for you to have a consistent experience as you go from one community to another. The technical infrastructure of today's online communities allow for no interoperability between them.

With the coming of federated network identity, this is likely to change; some form of interoperability between online social networks will probably emerge. Persistent identity will enable people to present a consistent set of personal data as they go from one website to another. The technical infrastructures of online communities may well adapt to the emerging environment, and add functionality that can leverage persistent identity data into new services. For instance, once this new functionality is in place, after you review a Grateful Dead album on Amazon.com, you may find yourself greeted with a link to a Grateful Dead discussion page when you enter AOL.

Given the current state of software development and the way new functionality is now being added to the Internet, the interoperability likely to emerge between communities -- if it comes about at all -- will be limited, and driven by commerce. Commercial entities like Amazon and AOL, for example, might arrange for data exchanges between one another for a fee. Information transferred between online social networks would probably be restricted to data meant to lead to a purchase of some kind, like of a Grateful Dead CD. In this scenario, no data exchange would take place for non-commercial purposes in the public interest.

Of course, there is nothing wrong with commerce-driven interoperability between communities. But a great opportunity to strengthen the public commons could be lost without a deliberate effort to develop community interoperability for non-commercial purposes.

What does interoperability between communities require? Servers and clients on the Internet are continually sending and receiving messages between themselves. These messages include requests for web pages, emails, domain information, and the like. The manner in which these messages are communicated is determined by sets of protocols -- standards that are agreed to and adopted by every website that wants to participate in the integrated system of the Internet.

ASN interoperability protocols will enable communication between the membership management databases of distinct online community infrastructures, so they can share ASN affinity-related data and provide automated interactions between individuals linked through trusted third parties. As discussed above, expressed affinities and capabilities would be kept as part of an individual's digital profile, managed by an identity service provider. ASN interoperability would allow for the exchange of this data between identity service providers and community infrastructures. These protocols would enable the infrastructures of Salon.com and Utne.com, for example, to make links between members who share affinities through the relationship each has to a mutual trusted third party. In addition, the protocols would enable the automated forwarding of media, and the creation of ad hoc social networks, based on expressed affinities with trusted third parties.

These protocols would establish a verifiable connection between each community member and his or her persistent identity, which would be maintained by an identity service provider. So whether you use six different names and present six different personas on a variety of different online communities, the membership management systems of those communities would have access to your persistent identities data. This introduces the potential for a dramatic shift in the way individuals present themselves in online environments, because, with such a system, anonymity online could become more difficult to maintain. In all likelihood, commercial federated network identity could well lead to the same result: the enforced continuity of persona in online environments. In fact, if commercial websites can turn persistent identity into additional revenue -- through merchandise sales, or special offers of fee-based content -- then the options for anonymity online are bound to shrink. Moreover, if commercial pressures ultimately determine the available forms of online representation, these formal options could easily succumb to the Hollywood blockbuster syndrome, and be reduced to a narrow range of obvious options, meant to appeal to the "lowest common denominator" consumer.

We believe it to be of the utmost importance that ASN interoperability protocols give individuals the broadest possible range of options regarding how they represent themselves in online environments. Identity in the real world is subtle, nuanced, and rich in its range of possibilities. The representation of self in digital media should similarly be multifarious and ambiguous, capable of reflecting an endless variety of interests, needs, desires, and relationships. A public interest approach to online identity, such as the ASN, could lead to the adoption of protocols that enable a wide range of possibilities for individual expression in online community environments. Commercial websites could then choose whether to make use of those protocols, or to ignore them. But the availability of agreed upon standards in the field would allow all websites, commercial or not-for-profit, to adopt them if they chose to.

A public interest effort devoted to this issue may be necessary to guarantee that online identity meets its potential to represent the full flavor of human interaction. The ASN community interoperability protocols would be a key part of such an effort.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Modular Community Applications

The ASN system will be accessed through email. Of course, that is not the only way that the ASN could work. Peer-to-peer and wireless technologies are emerging that might augment or replace email as the primary form of online communication in the years to come. It is the ubiquity of email that makes it attractive as a vehicle for the ASN. Since the system could be used to connect as many people as possible through trusted third parties, it is important that users be able to communicate with each other easily, using tools they are comfortable with. At the same time, nothing restricts the implementation of the ASN to email. The applications described below for email/community systems could be adapted for other forms of online communication, including peer-to-peer and wireless.

But for the purposes of this report, users of the ASN will communicate with one another through email that is available through online community infrastructures. That is, ASN electronic messages will arrive in an email "in box," be composed using the tools available through online community systems to create email messages, and be sent via the email "out box."

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### An ASN message will be one of three types:

* **Automated Introduction**. An automated introduction to another person who shares affinities or has complementary capabilities, based on the recommendation of trusted third parties.
* **Forwarded Media**. Articles, images or multimedia would be attached to an email message and forwarded among those who express shared affinities, based on the recommendations of trusted third parties
* **Ad Hoc Social Networks**. An ad hoc social network would be initiated by an individual sending a request for participation in a narrowly defined project, and would be forwarded based on express affinities and the recommendations of trusted third parties. The resulting ad hoc community, or swarm, would dissolve with the completion of the stated objective.

Bringing ASN activity to online community infrastructures will require additional applications beyond those online community systems provide today. New applications that enable enhanced search features, as well as the pre-processing and post-processing of email communications, need to be available to users of the ASN in order for the system to work. These applications would be developed as free-standing modules that can be "plugged-in" to existing online community infrastructures. They will need to allow ASN users to identify their messages properly when they are written, address messages in the appropriate manner (so that they are sorted and distributed by the ASN system), and send and receive messages in a way that distinguishes them from other email (so they are recognized as ASN messages when they arrive in an "in box").

Among the functionality that these applications would provide are the following:

* **ASN Search Interface**. Users of the ASN need to be able to access its distributed database of affinity and compatibility profiles through their online community tools. An ASN search feature is essential, in order for users to find others with whom they share affinities or have complementary capabilities.
* **ASN Composition and Addressing**. When creating an ASN message, users will need to designate the message as an "introduction," "forwarded media," or an "ad hoc social network." Properly designated and addressed, the message can be sorted by the ASN system, and sent to the appropriate recipients.
* **Tag Incoming ASN Messages**. When ASN messages appear in an "in box," they should
be tagged in a manner that distinguishes them from other email.
* **Filter Incoming ASN Messages**. When an incoming ASN message arrives, it should be checked to make sure that it has a header that identifies its subject as a relevant affinity, and that it indeed came through a trusted third party. A filtering mechanism is necessary to eliminate spam within the system.

In effect, the ASN calls for a meta-classification for online messaging that would allow certain types of e-communications to be separated from others, and to be sorted and presented differently than regular email. We propose to develop this additional layer of functionality as modularized enhancements to existing online community infrastructures.

All of these applications depend on the ASN being able to distinguish between relevant and irrelevant material, so that connections made between users are precise and appropriate. Above we referred to the ASN as providing "strategically placed doors" between social networks. The system's ability to be strategic depends on the sophistication of its active vocabulary. If it does not pick up on the nuanced intention behind a user's expressed affinity, then the ASN's utility is greatly reduced. At the same time, if it does not effectively parse the meaning of incoming ASN messages, it could subject users to spam. For this reason, the ASN application modules will incorporate sophisticated matching technologies (which are discussed below, in Section IV).

Advanced matching technologies, coupled with an efficient filtering system, should make the ASN difficult for spammers to abuse.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Reputation

An ASN automated introduction appears in your "in box," a solicitation from a stranger who found you through a mutual friend, a trusted third party. You read the email and it's interesting, then you check the author's web page, which increases your interest. Still, before replying, and perhaps offering other contacts of your own to this unfamiliar person, you might want to know more about him. Wouldn't you would want to know what kind of reputation he has among people he works with, for instance?

Over the last few years, reputation systems have appeared on websites and communities all over the Internet. Among the best known is eBay's, where buyers and sellers rate one another after completing transactions. Others range from Amazon.com, where buyers rate the reliability of used book sellers, to Epinions, where members rate the usefulness of the website's product reviews. As one article describes it, a "reputation system collects, distributes, and aggregates feedback about participants' past behavior."^21 In situations where many, if not most, of the people involved are unknown to each other, trust is hard to build because strangers "do not have known past histories or the prospect of future interactions, and they are not subject to a network of informed individuals who will punish past behavior toward any of them. In some sense, a stranger's good name is not at stake."^22

The ASN moderates this potential problem by only providing connections through trusted third parties. Reports of bad behavior are likely to get back to the person who made the initial introduction, which should dissuade most from abusing the trust extended through the ASN. Of course, if you hear bad things about a person you had expressed a shared affinity with, you would probably modify your digital profile so that it no longer expressed a strong affinity with that person. In this way, reputation indirectly effects the management of trust in the ASN.

Still, trust takes many forms. While the ASN should offer a level of assurance that its introductions are trustworthy, ASN users are likely to also refer to independent sources about a stranger's past behavior, at least from time to time.

With the growing adoption of reputation systems on community websites, this kind of cross-referencing will become increasingly possible. As one paper reports, "The proliferation of online reputation mechanisms is already changing people's behavior in subtle but important ways. Anecdotal evidence suggests that people now increasingly rely on opinions posted on such systems in order to make a variety of decisions ranging from what movie to watch to what stocks to invest in."^23 These opinion generating systems are becoming common on online community infrastructures. But the opinions they offer are only relevant to the specific context of the community interactions where they take place.
On Epinions, for instance, a person might develop the reputation of being a lousy film critic. That same person's reviews, however, could be highly regarded on another website.

There are some who suggest that reputation should be portable between communities -- that the ratings you get in one environment, based on one set of circumstances, should be available in other environments, where the situation might be quite different. For instance, shouldn't a seller's rep on eBay be available on Amazon.com? This raises the possibility of a kind of online "universal reputation," which might even be part of your persistent identity. In Smart Mobs, Howard Rheingold asks, "Are universal reputations systems possible?"^24

Strictly from the perspective of technology, they might be. A global Internet aggregator of Web-based reputation data is a real possibility. But would such a system accurately reflect the way reputation works in the real world? That is a different matter. Reputations are determined by context. What is viewed as bad behavior by one group might be perfectly acceptable somewhere else. How would a "universal reputation system" take shifts in context into account? We do not believe it to be possible.

For that reason, when designing the ASN, we made it a point to not include a "reputation rating" as part of an individual's persistent identity. Each online community is free to set its own standards for determining reputation; every social network invariably sets its own criteria of trustworthiness. But the opinions of others -- which are the product of widely divergent circumstances -- should not be grafted onto the permanent representation of an individual online.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Reputation is local; it belongs to specific communities. Persistent identity is global.

As federated network identity is adopted, civil society groups need to press for protections against the aggregation of this reputation data -- much of which is proprietary, controlled by commercial entities that can do with it much as they please. Soon the day will come when profitable businesses could process reputation data and resell it to customers ranging from credit card companies to retailers to media conglomerates. Knowledge about reputations, even when less than accurate, is always valuable. But just because something has market value does not mean that selling it serves the public interest.

<p><sub id="cite-21">(^21) Resnick, Zeckhauser, Friedman, and Kuwabara, "Reputation Systems: Facilitating Trusted Internet Transactions," 2000.</sub><br>
<sub id="cite-22">(^22) ibid</sub><br>
<sub id="cite-23">(^23) Chrysanthos Dellarocas, " The Digitization of Word-of-Mouth: Promise and Challenges of Online Reputation Mechanisms," October, 2002.</sub><br>
<sub id="cite-24">(^24) Smart Mobs, p.127</sub><br></p>

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Current Community Systems

What kind of online community infrastructure best supports communities of practice? A community infrastructure can entail many things. The phrase "community infrastructure" is generally understood to have the broadest possible meaning: the integrated set of digital communications tools that allow members of a social network to communicate among themselves. This definition would include everything from a simple email listserv to a high end corporate intranet. The fact is, to this day, there is no agreed upon set of communications tools that constitutes a standard "online community infrastructure," let alone one that provides a specific tool set for communities of practice. Though some theorists might hypothesize about what one might be, we are far from seeing such a system.

In fact, the community-ware landscape today includes the products of some 90 different companies, all of whom offer one flavor or another of digital communications tools for social networks. Of course, not all of these lend themselves to use by communities of practice. Cynthia Typaldos' 12 Principles diagram suggests the range of social interactions within a community of practice that need to be taken into account by the technical infrastructure, and in the establishment of norms of behavior for the social network online.

In the preparation of this report, while looking for potential partners in the development of the ASN, we identified 10 community-ware efforts that provide well-considered suites of tools to support communities of practice. We deliberately did not include the efforts of the software Goliaths, like IBM or Microsoft. Rather, these efforts are being spearheaded by smaller, independent companies, in some cases by not-for-profits. Several of them have a strong commitment to serving the public interest. They are:

* Real Communities/Mongoose
* Communispace
* Community Zero
* Tomoye
* Plumtree
* Friendly Favors
* Friendster
* Plaxo
* Spoke

Some of these companies are already implementing advanced matching technologies. Others have begun to offer automated or brokered introductions between members. All of them are committed to offering a full suite of applications to support sophisticated online collaboration, and could well see the ASN as an attractive addition to the services they offer their users.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

### IV. Public Interest Matching Technologies

#### The Purpose of Matching Technologies

The ASN will allow knowledge and relationships generated inside one online community to be shared with others. The expertise that one social network has cultivated about solar energy, for example, would become available to other groups with common objectives, through the recommendations of trusted third parties. This kind of targeted, effective information flow would benefit the entire solar energy field, as it would enhance the discourse and relationship building of many public interest efforts.

But even with the communications architecture of the ASN in place, what will ensure that the introductions it provides will be appropriate? How will the ASN assist communities in assembling and using their collective knowledge? How will communities discover relevant knowledge that has been assembled by another group? After all, different social networks will use different language to describe similar subjects. In many instances, the words used to discuss the same things in different online communities won't match. Would the search and brokering mechanisms of the ASN still be effective? Could the ASN provide active assistance in extracting useful content from the glut of available material?

These are the kinds of questions that prompted Tim Berners-Lee, the inventor of the World Wide Web, to spearhead the "Semantic Web"^25 initiative in the late 1990s. One of the great strengths of the Web is its ability to create links between relevant materials. But if search results don't turn up important, related materials because of variations in exact wording, if automated agents can't identify matches between web pages because of differences in context, then those links might not be made.

As Berners-Lee put it, "The Web was designed as an information space, with the goal that it should be useful not only for human-human communication, but also that machines would be able to participate and help. One of the major obstacles to this has been the fact that most information on the Web is designed for human consumption, and even if it was derived from a database with well defined meanings (in at least some terms) for its columns, that the structure of the data is not evident to a robot browsing the web."^26 Elsewhere Berners-Lee explained, "The Semantic Web will bring structure to the meaningful content of Web pages, creating an environment where software agents roaming from page to page can readily carry out sophisticated tasks for users."^27

Today, of course, the Web is highly prized for its hyperlinks, an ability that Berners-Lee designed into the system in the 1980s. At the time, however, he did not consider hyperlinks to be the Web's most attractive characteristic. Rather, he thought that its greatest value would come from providing a "community memory" for the scientists who use it. This notion of a community memory -- a kind of collective consciousness -- readily available to all of its members, introduced new possibilities for knowledge sharing and collaboration between scientists.^28 Berners-Lee was particularly interested in how a distributed digital repository for knowledge could serve a particular community (in this case, the scientific community). For that reason, he understood the importance of classifying and organizing Web content so that relevant material could be easily discovered. However, once it was introduced, the Web took off at such an astonishing rate that the attention and resources necessary to establish an online system for semantic organization were not available. Only in the late 1990s was Berners-Lee able to get the field to focus on the problem of meaning-making online.

The Semantic Web is the most prominent of a family of initiatives that can be grouped under the rubric "matching technologies." These matching technologies are advancing on many fronts. But, as might be expected, much of what is being done serves corporate rather than public interests. If these systems are not developed to address civil society topics, or are not designed to serve community infrastructures outside the corporate realm, then civil society discourse will be deeply impoverished. Today, matching technologies that could be used for civil society initiatives are only rarely being applied to them; the bulk of this work has catered to the needs of business. Because resources are not being put toward public interest applications of matching technologies, civil society groups lag behind the corporate sector in this important area. While commercial interests use the Internet with increasing effectiveness to access information about topics like energy, health, and food, civil society groups are left with no other option than use the semantic tools designed by the commercial sector (in the rare event that they even have access to them). In practice, this means that connections made online between relevant materials in a particular field will follow a map of meaning drawn by industry. As a result, connections that reflect alternative views of the same material might be increasingly difficult to come by. It would be as if the definitions in the Oxford English Dictionary were only written by businesses with a vested interest in them, with the final wording approved by the highest bidder.

Certainly, the ASN would be much less useful without a robust system of public interest matching technologies. In fact, the ASN's usefulness relies on its ability to identify relevant relationships and information (through trusted third parties). While matching technologies are important to the arena of information search and sharing, they are just as essential to the infrastructure behind persistent identity, rights management, and the enabling of software assistance agents. To use an example from the scenarios above, if Jim, who is a member of one social network focusing on solar energy, and Bob, who is a member of another, are not using the exact same language to describe issues of common concern, that might keep the ASN introduction system from bringing the two together. But if sophisticated matching technologies were applied to the topic of solar energy, then the differences in language would be overcome. The ASN would be able to identify the potential for useful collaboration between Jim and Bob, and provide the introduction between them. It would also be able to finely hone the expression of an individual's affinities, so that each ASN user can express personal interests with a great degree of granularity.

Sophisticated matching technologies lead you to the content that most interests you, while filtering out the rest. Automated agents depend on them. Not only do they enable robots to connect to the appropriate material, they also restrict connections. Which is to say that matching technologies are key to the filters that reject spam.

<p><sub id="cite-25">(^25) The term was proposed by Tim Berners-Lee, in a 1998 paper titled “<a href="http://www.w3.org/DesignIssues/Semantic.html">Semantic Web Road Map</a>”</sub><br>
<sub id="cite-26">(^26) Ibid.</sub><br>
<sub id="cite-27">(^27) "The Semantic Web," By Tim Berners-Lee, James Hendler and Ora Lassila, Scientific American, May 17, 2001. For more, see also <a href="http://web.archive.org/web/20181208154756/http://semanticweb.org/wiki/Main_Page">http://www.semanticweb.org</a>.</sub><br>
<sub id="cite-28">(^28) Berners-Lee's concept of a digital, networked community memory owed much to the writings of pioneers from the 1960s such as J.C.R. Licklider, Douglas Engelbart, Robert W. Taylor, and Ted Nelson, among others.</sub><br></p>
<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Matching Technologies and Online Community

The ASN applies matching technologies to online community infrastructures in order to support the introduction of people based on common interests. It would integrate matching technologies into online communities at a high level. How would they enhance a user's experience of online community? They would help in these areas:
* Representing personal identity and interests. Personal profiles in a community system are more useful (more automatable, discoverable, meaningful, and trustworthy) given shared agreements about the meaning of terminology. The technology for automated matchmaking and personal rights-management depends on matching standards being developed for the agent-mediated “semantic web”.
* Representing community identity and interests. A community can present itself more clearly to others if its guiding interests and activities are described rigorously.
* Improved access to community documentation.
* Improved access to external documentation, using navigation aids prepared by one’s community or the community owning the external documentation, or by a third party. Navigation aids are shared. Furthermore, new insight might come from combining navigation aids.
* Improved knowledge sharing. Knowledge from a specific community often has value beyond its community of origin.
* Knowledge creation from ordinary work practices. Collaborative filtering and other knowledge extraction technologies can aggregate community knowledge without extra work in assembling information.
* Improved relevance in message routing and news services. * Ontologies can codify practices as well as descriptions.
* Ontologies could potentially codify personal relationship types. Agents could broker introductions. Codified relations can be transitive, within limits.

The "next generation" of online communities now being developed have begun to add elements from the list above to their infrastructures. But by no means has a standard community "tool kit" to support matching technologies emerged. Moreover, little attention has been paid to how the knowledge created inside each "walled castle" community could be exchanged with those outside its walls. The exponential benefits of connectivity (remember the discussion of Reed’s Law from the Communities section) will be realized when the matching technologies allow focused interconnectivity between community groups. One of the purposes of the ASN is to make this kind of interoperability commonplace on the Internet -- and to raise the bar of expectations for what online communities serving the public interest ought to deliver.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Federating Meaning, Decentralizing Knowledge

> “Communities of interest are defined by their worldviews, and whenever a community of interest rigorously exposes its worldview in a fashion that permits its knowledge to be federated with the worldviews and knowledge of other communities, the whole human family is enriched” -- Steven Newcomb

Can online communities better collect, represent, and share the meanings of the content they produce so that the collective knowledge of communities can be more available to others? Implicit in this question is a concern with the way online content is organized and classified, in order to make its meaning more accessible. It is an approach that leads to software and standards that overlay content with rich descriptions of meaning and association. Once the content is "understood" by the system, it becomes possible to make relevant matches between items.

This approach to matching technologies relies on the implementation of sophisticated ontologies and taxonomies -- broad, structured maps of meaning, and carefully honed definitions that pinpoint each subject's place on that broad map. Sometimes referred to as "knowledge mapping," this technique provides a framework for the organizing of content so users can access it by navigating a familiar field of meanings. For a system like the Semantic Web, ontologies and taxonomies are key.

Establishing meanings in this way has long been a laborious task. It should go without saying that determining ontologies and taxonomies is not a job that can be done adequately by a machine. In the past, most online ontological systems were by necessity assembled by information specialists. More recently, distributed technologies offer the possibility for non-specialists to participate in classifying and describing information resources that they use. Each social network could potentially organize its own maps of meaning for the materials they rely on, and are expert in. New technology allows them do this explicitly, or as a serendipitous side-effect of their daily interactions with one another and with the various documents they exchange with each other. By exploiting these beneficial side-effects, knowledge structures could emerge as the result of the interactions of a particular community -- they would be a collaborative expression of the ideas and world view of that social network.

Meanings are never obvious. This is why communities of practice adopt formal vocabularies, so that ambiguity can be reduced and clarity improved. Every professional field develops its own distinctive vocabulary; since the same word is often used to mean different things in different contexts, establishing agreed-upon vocabularies is essential for precise communications. The medical field, for instance, relies on a well-understood standard vocabulary to exchange information about research, treatment, and billing. Each community of practice has to decide the structural context in which important words are used -- the ontology -- and the specific definition of important words in that context -- the taxonomy.

In the library sciences, an ontology is referred to as "a formal shared map of concepts and meanings." In most cases, it is a conceptual architecture that represents individual subjects and the relationships between them. For example, an ontology for the topic of solar energy would map all the main issue areas relevant to solar energy, show their relationship to one another, and assign specific meanings to words associated with each of the issues. In effect, ontology builds a layer of meaning over the topic it covers.

A key element of the ASN is the creation of public interest ontologies and taxonomies that focus on specific civil society topics. These would be developed in collaboration with NGOs and public sector organizations working on subjects such as energy, hunger, water, and other aspects of civil society. This initiative would apply technologies such as XML, RDF, and Topic Maps to public interest subjects. The intent is to make available to engaged citizens the powerful communications tools now being developed and used by the commercial sector.

Of course, every social network sees things somewhat differently; they will have contrasting opinions, different priorities, and alternative interpretations of the same material. The solar energy field, for example, contains a wide range of opinions and approaches. For this reason, no one ontology for a particular topic is sufficient. Rather, it is important that all "meaning making" technologies facilitate multiple points of view of the same information. Who decides how information is classified, what the ontological map of a topic (like solar energy) should be? Shouldn't the stakeholders in a particular community be able to determine this for themselves? Today that work is only being done by those with the resources to do it -- primarily in the commercial sector. Significantly, the ontological systems they are developing are not interoperable, they don't speak to each other. As a result, if an ontological map about a topic (like solar energy) takes hold as a market leader, its assumptions about relationships between issues, priorities in the field, meanings of specific terms, etc., become the de facto standard for all social networks working on that particular topic. Even if other ontologies are developed, they could be marginalized, pushed to the periphery by the widespread adoption of an easily available, commercially underwritten system.

It is also worth noting that the commercial systems for forming ontologies have no incentive to use open standards. In fact, they might be inclined to use proprietary software designed to work in narrowly defined contexts, in part because they see no reason not to. But by not using open standards, they create an additional challenge to interoperation between ontological frameworks.

As part of the ASN, we would support open standards, and develop protocols for the interoperability of online ontological frameworks. This approach would promote the decentralized control of meaning-making online. At the same time, it would enrich discourse by allowing separate social networks to share their "knowledge maps" with others, so that diverse viewpoints could be accessed and comparisons made. Ultimately, a multitude of independent maps could be applied to a single collection of information.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Using Tacit Knowledge

The approach described above focuses understanding the meaning embedded in information resources, and mapping that meaning so it can be navigated effectively. But there is another technique now being developed to help users discover relevant information from a sea of bits and bytes -- an approach that cares little about the actual "meaning" of data.

Can the meaning that is present in online documents and relationships be extracted so that automated agents can act "as if" they understand those meanings, enabling more relevant search results? The technologies based on this approach will look for patterns that emerge from the online actions of individuals, or that can be identified by analyzing a set of online content. They are less concerned, and sometimes completely unconcerned, with the "meaning" of the content itself. Rather, by analyzing the patterns created by elements within a particular online environment, certain relationships can be deduced. This approach is known as "tacit knowledge discovery." It is familiar to users of Amazon, for instance, where a "tacit knowledge" recommender system suggests books that might interest you based on your purchases. The system does not have to "know" the content of the books you like, but only how your buying patterns compare to those of others on Amazon. Pattern-based systems of this kind are now being deployed as part of the knowledge management tool kits built into advanced corporate intranets. They are often used to analyze email and other intra-company communications to connect employees working on compatible projects.

Extracting tacit knowledge from online content, bringing knowledge to the surface where it had previously gone unnoticed, has become a hot topic in certain IT circles. The approach of looking for patterns that emerge from the online actions of individuals, or that can be identified by analyzing a set of online content, has proven to be extremely powerful. The public first became aware of these kinds of tools in the mid-1990s, when a music website named Firefly introduced a technology known as "collaborative filtering." Once a user expressed preferences for certain artists, the website would be able to recommend other artists that the user might find of interest -- based strictly on the preference patterns expressed by other users.

In recent years, the concepts underlying this approach have been expanded in a wide variety of ways. They have led to the recommender systems now common on e- commerce sites, like Amazon.com. The technique has proven less successful on community sites, where its utility has not been clear. This might be because discernable patterns may not emerge among communities that are not engaged in easily definable objectives. It is possible that tacit knowledge techniques work best among communities of practice.

This could explain why only one form of online community has incorporated tacit knowledge effectively: advanced corporate intranets. These knowledge management systems have used tacit knowledge to make connections between individuals and the areas of knowledge in which they appear expert. This kind of tacit knowledge system does not attempt to capture and catalog the specific "knowledge" that an individual might have. Rather, it identifies patterns in the online communications and actions of individuals, and infers from them that connections exist between certain people and identifiable topics. It can also identify (by inference) particular individuals who are regarded as trusted experts on particular issues This technique could prove to be important to the technical infrastructures of third party brokering services within the ASN, enabling them to infer affinity matches between individuals in an efficient and effective manner.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Conclusion

These two approaches -- ontologies and taxonomies, on the one hand, and tacit knowledge, on the other -- are different ways of attacking the same basic problem. Both are of importance to the public interest sector. Moreover, as they develop, these separate tracks will become increasingly interdependent. For example, a recommender system on Amazon might sift through reviews you have written, and cross reference the meaning of your text with the buying patterns of other Amazon customers who have expressed similar interests. These systems are becoming increasingly sophisticated. They ought to be put in the service of civil society. The ASN will facilitate balanced, flexible interactions among the two types of tools.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

### V. Brokering Services

#### The Introduction Protocol

The essential activity of the ASN is that it brokers introductions between people across social networks, based on expressed affinities and capabilities, through trusted third parties. In order for those introductions to take place, there have to be rules that guide when introductions can be made and how they are facilitated. Each of us responds to unsolicited introductions differently. Some of us are thrilled to meet new people, while others prefer not to be bothered except rarely, under very limited  circumstances. Moreover, across the globe there are cultural differences that influence the formalities that people go through when they meet one another -- it is far from "one size fits all." The kind of brazen, unsolicited introduction that is rewarded in San Francisco is considered rude in Japan. Or, for a more provocative example: under what circumstances would a Palestinian student welcome an introduction to an Israeli peace activist? How can the ASN's introductions be sensitive to this variety of social situations and contexts?

Clearly the ASN needs to provide a range of introduction options, so users can choose what is right for them. These options, and the rules they would follow, would be determined by a set of "introduction protocols" -- explicit instructions about the sequence of actions that would automatically take place before an introduction is facilitated through a trusted third party.

In most cases, it is likely that the introduction protocol would not need to be particularly sensitive to cultural differences or complex social dynamics. As with email, live chat, or SMS (mobile phone texting), people from a wide range of backgrounds will figure out their own personal comfort zone for using a standard set of simple tools. They will likely shape their use of the ASN to fit their own cultural expectations for social interaction, as long as the system is easy to use, respects privacy, and has utility. For these circumstances, which should be the vast majority, there would be a "plain vanilla" introduction protocol that brokers basic introductions within existing online community systems, as discussed in Section III.

What would this protocol do? It instructs an automated agent (or  broker-bot") to follow a sequence of actions that would lead to relevant introductions. It tells the broker-bot to read the "affinity reference" in a user's digital profile, and then match those expressed affinities or capabilities to others with complementary interests, based on links through trusted third parties. The broker-bot would be instructed to use the ontological frameworks (discussed in Section IV) as a guide to determine meaningful matches. At the end of this sequence, the broker-bot would send a specially tagged ASN Introduction email to the match that it found, without copying the person who made the original request. That "discovered match" can then decide whether to reply to the introduction, or not. If the "discovered match" does not reply, the person who made the initial inquiry would never know, and so would not feel slighted by the rejection.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Specialized Brokers, Customized Introductions

This plain vanilla version of the introduction protocol would provide a basic level of the ASN service -- which in itself should prove useful in most situations. But it would not allow for a great deal of customization. What does that mean? If you wanted to use the ASN to connect Israelis and Palestinians in order to support the peace movement, you might want to modify the introduction protocol so that it brings a greater level of certainty and security to the interaction. You might also want to have a real life intermediary interpret the results of automated searches and matching, to act as an additional filter before introductions take place. In situations where an inappropriately made introduction could be a matter of life or death, you would want to customize the ASN to provide the highest possible of level of confidence.

Other concerns are raised by what might be called "The Bono Dilemma." Suppose you worked with Jubilee 2000, the debt relief NGO, and through that work knew Bono. It is unlikely that you would allow an automated system of trusted third parties to take advantage of your access to the rock star/activist. Rather, you would be highly selective when offering your trusted relationship with Bono to another person. At the same time, you know that Bono would be genuinely interested in meeting certain, highly qualified experts working on hunger issues in Africa. But the basic "introduction protocol" of the ASN would not provide enough information and verification for you to feel comfortable vetting a stranger who claims to be such an expert, even if she comes to you through a trusted third party.

For cases like these, there is a need for specialized, independent brokering services that can customize the information protocol so that it meets the requirements of particular groups. A brokering service that specializes in global hunger activism, for example, might be offered by Jubilee 2000, or by a consortium of organizations working on related issues. Their expertise should fine tune the details of the "introduction protocol," making it context specific. In this case, that might mean checking the references of people who claim to have done relief work, or posting online CVs that have been carefully vetted. It might even include the timely appearance of a real-life intermediary to evaluate claims made, or to test the waters to see if an introduction would be well received by the intended recipient. With such a vetting structure in place, designed specifically to serve the needs of a particular group, you are more likely to use the ASN to refer someone to
Bono after all.

Customized introduction protocols and services could be designed for a wide variety of situations. Among them are:

* **Verifying reputations before completing matches**. Because reputation depends on social context, an individual's persistent identity should not include any kind of "reputation rating." Still, when you enter a new online community, and make claims about your past that are relevant to that community, reputation checks make sense. A reputation check on a global hunger brokering service, for example, could provide the vetting necessary to
solve the "Bono Dilemma."
* **Brokering introductions between people from different cultures**. Chinese and New Yorkers, to cite one of an infinite choice of examples, follow sharply different cultural practices in the establishment of trust between people. Special introduction protocols could help negotiate these differences by automating steps in the formation of trust that bridge the distance between cultures.
* **Cross-referencing different matching technologies for better matches**. Above we discussed the value of comparing different ontological frameworks of the same set of data. A brokering service could automate this process, to give greater depth to searches made by its users. For example, a global hunger brokering service might layer the ontological frameworks written by African-based NGOs, the UN, the EU, and the World Bank, each of which would bring different readings and associations to the data set -- leading to search results that make unexpected connections, and particularly useful matches. In addition, it might cross-reference those results with a tacit knowledge recommender system built into the bulletin boards on Jubilee 2000's website. In this way, the global hunger brokering service could provide extremely useful matches meant for an expert constituency.
* **Using real-life intermediaries to make solicitations**. There will be times when an automated introduction simply won't do. In those situations, brokering services could offer trusted, real-life intermediaries to make an initial solicitation. If that solicitation is accepted, than an introduction would take place.

These customized introduction services, among many others, would be offered by independent brokers, which would mix and match protocols, shaping them to meet the needs of their constituents. Brokering services could either be for-profit companies, or not-for-profit civil society initiatives. A brokering service could be hosted on a single destination website (like About.com, where you go to their online "front door" to use their services), or it might syndicate its services on many other sites (like Amazon.com's Affiliates program, which allows a multitude of websites to create their own e-bookstores by linking into Amazon's backend). Our interest is in allowing for the widest possible variety of these services to take shape -- which means that the basic introduction protocol has to be written to facilitate this wide range of customization while maintaining interoperability.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Current Brokering Systems

Many websites today have some kind of introduction service. We discussed some of these earlier, in the context of matching technologies. For example, Amazon.com's recommender system matches people with books they might be interested in. From the standpoint of the underlying technology, matching people to books is not hugely different than matching people to one another. For that reason, the tacit knowledge approach that drives a book recommender is quite similar to the mechanisms used by advanced corporate intranets with sophisticated knowledge management systems. The intranet, though, is designed to connect employees who are working on complementary projects.

These and other matching technologies are used on dating sites like Match.com (which claims responsibility for over 1,200 marriages and 50 babies!).^29

Most of these systems, though, are meant to serve narrow purposes. They are not designed to be interoperable, to exchange information with other sites. Moreover, the brokering mechanisms they use tend to be limited (customized around one ontological framework, meant for a very specific context and use) and proprietary. While the core technology is similar, these implementations are not appropriate for the kind of Internet-wide relationship and knowledge sharing called for by the ASN. They don't use anything resembling an introduction protocol that could be used by others.

A number of online communities, however, have begun to develop tools meant to engender various types of networks of trust, and they point in the direction of an Internet- wide system like the ASN.

One such site is Friendly Favors^30 , an online community with some 25,000 members in 152 countries, brought together around a shared vision of global justice, which they describe as "a World that works for us All." The site includes member biographies where users can express affinities and capabilities, as well as a simple reputation system, which allows members to vouch for the "Identity" or "Integrity" of others. New members are encouraged to find "Sponsors," who do the vouching, and who can "invite you into our network's web of trust." "This simple safeguard," explains the site's front page, "has allowed FF to build an intricate network of trust around the world, where an open and transparent accounting of people's good deeds is allowing us, for the first time, to reliably identify the most generous ones among us."

Friendster is basically a dating service, but it also encourages people to form other kinds of relationships -- because introductions through the system only take place through trusted third parties. So the more people you know on Friendster, the more potential dates you can be introduced to. As they explain on the site, "Friendster is based on networking through your friends. Your photo and profile will be shown only to people in your personal network. You will send and receive messages only with people connected to you through a series of mutual friends. You will be able to see how you are connected to people you are interested in, and either contact them directly, or ask a friend to make an introduction."^31

Another interesting effort, relevant to the ASN, is Plaxo, a peer-to-peer contacts updating system. Plaxo is an application that you download over the Internet to your hard drive, and "plug-in" to your email client (such as Microsoft Outlook). It then communicates with every other Plaxo client on the Net, enabling you to trade business card information with those people. As they move, change jobs, change phone numbers, etc., Plaxo automatically updates their business card information on your computer. While it does not offer brokering services between Plaxo users, based on their business card information, a service that does so is an obvious next step.

But perhaps the most forward thinking company in the area of brokering services is NetDeva. Under the leadership of Duncan Work, the company has developed the prototype of an automated agent that matches people based on their affinities and complementary capabilities through the recommendations of trusted third parties. It is a peer-to-peer system, with an application installed on the user's desktop. As the website explains, "Net Deva's powerful intelligent agents help users easily manage complex, time-consuming tasks. One of these agents is a loyal and skilled personal assistant to help users manage their most important relationships; another acts like a highly connected and secure relationship broker to help expand their personal connections."^32 While it is a proprietary system, much of the technical development that Net Deva has pursued -- which has focused on how to cross-reference, search, and match expressed affinities and complementary capabilities against trusted relationships -- is directly relevant to the ASN. While NetDeva has been designed to meet the needs of business, as part of
advanced corporate intranets, the company has shown strong interest in making NetDeva available to civil society initiatives.

Alongside NetDeva, a handful of other commercial brokering efforts are about to be unveiled to the public. These companies will significantly raise the bar for brokering services available to corporations and government. The technology will deliver the kind of affinity based brokered introductions that the ASN calls for. However, all of these systems are proprietary. None of them are designed for interoperability. And none of them will be applied deliberately to public interest initiatives.

<p><sub id="cite-29">(^29) <a href="http://www.match.com/registration/aboutus.asp">http://www.match.com/registration/aboutus.asp</a></sub><br>
<sub id="cite-30">(^30) <a href="http://www.favors.org/FF/">http://www.favors.org/FF/</a></sub><br>
<sub id="cite-31">(^31) <a href="http://www.friendster.com/info/moreinfo.jsp">http://www.friendster.com/info/moreinfo.jsp</a></sub><br>
<sub id="cite-32">(^32) <a href="http://www.netdeva.com/product.html">http://www.netdeva.com/product.html</a></sub><br></p>

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

## PART 3: Strategies for Implementation

### I. Software Development in the Public Interest


The necessary technology for the Augmented Social Network might already exist, but making the ASN real will be a challenge. It will require an effort far beyond any software development that civil society organizations have achieved to date. Of course, many more complicated technical projects that effect the Internet are accomplished all the time. But those efforts tend to start with the communications or software industry, and are shepherded by well-funded organizations that represent industry interests. Funding for these projects are based on business plans that anticipate profits. Needless to say, the ASN doesn't lend itself to this kind of approach. (It is worth recalling that neither email nor the Web were justified by business plans when they were invented, nor would that have even been possible.)

Suffice it to say that the ASN is unlikely to become an industry priority. It does not offer immediate avenues to profitability. Some aspects of it -- such as the writing and updating of public interest matching technologies -- will probably always have to be subsidized. Others challenge current assumptions in the business models of for-profit online communities, which have been deliberately designed as "walled castles" that do not permit interoperability. In the business world, legacy attitudes about intellectual property and the jealous guarding of customer information have trouble accommodating the 21st century realities of data flow and online collaborative behavior. Even if business leaders "get it," it is doubtful they will lead the charge for the ASN. That should not be surprising, since the ASN is designed in no small part to correct the oversights of the business community as it expands capabilities on the Internet. This work, by its very nature, has to be led by the civil society sector.

During the dot com heyday, it was widely believed that if software was any good, it would make someone a profit. For that reason, there did not seem to be a need for what you might call "not-for-profit software development." Civil society groups tended to let the market determine which tools were built, and who they were targeted to serve. While there was a certain amount of support from the foundation community for public interest website development, which included the creation of specialized mailing list and e-marketing tools to support non-profit initiatives, those efforts were relatively few compared to the extraordinary explosion of digital media in the commercial sphere. And often those public interest websites were expected to become self-sustaining by following the business models established in the commercial sector.

Once the dot com bubble burst, attitudes changed. There was far less expectation in the public interest sector that online projects would become profitable. But these diminished expectations were accompanied by a distrust of digital media in general, as many people felt that they had been hoodwinked by unscrupulous Internet hypesters as once inflated stock prices were reduced to pennies. As a result of this, as well as in reaction to the sharp downturn of the economy, the civil society sector has shied away from large-scale, ambitious online initiatives. Not only has little interest been shown in complex digital media projects, but the civil society sector has barely begun to develop the capacity to evaluate potential projects, to determine whether they should even be considered for support.

Today the civil society sector is simply unprepared to engage with the critical issues facing the build out of our digital communications infrastructure in anything other than a reactive fashion.

**What does this mean for the ASN?**

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

#### Hybrid Approach

The ASN could be achieved in an incremental manner, with software and protocols developed among a relatively small group of participants, and gradually adopted by larger online community systems as they see fit. The development of the software and standards would best take place as part of pilot projects that introduce ASN functionality to a small group of online communities that can participate in working kinks out of thesystem, preparing it for a broader launch. These online communities could be either not-for-profit initiatives or for-profit companies, or a combination of the two.

The Internet itself supports many kinds of business models. A good deal of them are based on open standards that are shared freely by many players, and which are maintained and updated in a collaborative fashion by standards bodies that represent diverse interests. We believe that in order to be successful, the ASN would have to follow an open standards approach.

The writing and adoption of standards is a complex matter. Moreover, the ASN faces an additional challenge because it requires coordination between technical disciplines that have no experience collaborating with one another. It remains with the civil society sector to facilitate this activity.

But once the ASN is in place, it offers a range of opportunity for companies that could generate revenue by providing features of the overall system. These include:

* Community sites that have incorporated ASN functionality.
* Personal identity companies that offer identity services that cater to specific
communities.
* Boutique brokering services that charge for specialized introductions.
* Specialized search services that use customized ontological frameworks.

As with email or the Web, ASN functionality could become a core part of the Internet experience -- as well as a revenue source for profitable businesses that provide online services.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

### II. Principles of Implementation


The intent of the ASN is to increase interconnectivity between people by enabling them to more easily find and share relevant relationships and information. Clearly, engendering trust in the system is critical to its success. To that end, it is necessary for the implementation of the ASN to be guided by principles that support such an environment of trust. These principles include:

* **Open Standards**. For this system to be broadly adopted, it must be transparent so that all of the entities that participate in it are reasonably assured of its trustworthiness. This means that the software code that enables the system should be non-proprietary and freely available, and that the process by which the software is written and the standards enacted should be open to the highest levels of scrutiny.
* **Interoperability**. Our vision is of an Internet with more bridges and fewer walls, where the individual can travel easily between communities. To enact this vision, online communities need to consider ways of being open to one another. Interoperability between diverse environments and ontological frameworks is central to this effort.
* **Inclusivity**. For the system to successfully draw in the largest possible number of participants, and to enable free connection between potential correspondents, it must be designed to embrace every online community that agrees to its standards and principles. In this regard, the ASN must be value-neutral, open, and inclusive, not unlike the open
connectivity of the underlying Internet protocols.
* **Respect for Privacy**. The ASN should be a galvanizing force for the strengthening of privacy protections online, in support of a thriving civil society. Every person online must be certain that private information remains private, and that neither governments nor commercial interests will use this information in any way without the individual's knowledge and expressed permission.
* **Decentralization**. The Internet works best when systems are not commanded from the top down, but rather emerge from the bottom up -- and are then adopted on a voluntary basis, in a manner that best suits the specific needs of the distinct communities that together comprise the Net's totality. We are in favor of an "opt-in" system, rather than one commanded by a government or commercial authority. For that reason, our approach
is to develop software and standards that can be added to existing community operating systems in a modular fashion -- so they do not have to rewrite their software from scratch, but rather can "plug-in" these modules to their existing infrastructures. Similarly, the ASN would support decentralized structures for the maintenance of persistent identity and ontological frameworks.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

### III. Recommendations


In the near term, there are a number of practical steps that should be taken to bring the ASN into being. While some of this work could be pursued as for-profit/not-for-profit hybrids, our inclination is to support this work strictly through grants, and to make the fruits of these efforts (the software and protocols they lead to) freely available to the public through GPL (and other similar) licenses. These steps include:

* **Establishing an ASN coordinating body**. The ASN effort needs to be led by a public interest, not-for-profit body that articulates its mission, advances its objectives, and commissions and coordinates efforts in a variety of different fields that together contribute to the creation of the ASN. An important aspect of this work would be to bring the ASN vision for the "next generation" Internet to the public, creating an international constituency to support this work.
* **Convening a board of technical advisors**. An interdisciplinary team of engineers should prepare a detailed technical architecture for the ASN. This team should report to a board composed of highly regarded technical advisors, who would review and vet the architecture, and guide the technical growth of the system. The board would also review the technical work done by ASN engineers who develop software and protocols.
* **Providing a dedicated engineer to represent the public interest at standards bodies working on persistent identity**. An engineer expert in the area of persistent identity should be sent to take part in the critical standards meetings of the Liberty Alliance, Passport's .Net initiative, and other efforts to introduce persistent identity. This engineer should push for standards that will insure the implementation of civil society-oriented "affinity references," as well as their availability to interact with "introduction protocols." In addition, this person should vigorously present a civil society perspective on privacy and public commons issues.
* **Co-develop basic ASN functionality with select online community companies**. Basic ASN community functionality should be developed through a pilot project that involves a small number of communityware companies open to collaborating on key issues such as: interoperability, affinity based introductions, and ontological frameworks. This work would include the writing of the introduction protocol. This pilot project would be a testing ground for the implementation of ASN functionality as it develops. Ideally, at least one of these online communities would include the active participation of one or more NGOs, in a particular field, in order to test the effectiveness of the ASN under the stresses and strains of actual use. It could also include the participation of one or more of the independent brokering services now developing technology for corporate intranets.
* **A dedicated team would coordinate implementation of matching technologies for the public interest sector**. The ASN effort should act as a catalyst to bring attention and support to the development of ontologies and taxonomies for the public interest sector. A pilot project to begin this work should be initiated in collaboration with one or more NGOs.


<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

## Appendices
### A. Acknowledgements 

This paper is the product of a two-year process involving over fifty professionals from the fields of network computing, independent media, and environmental activism. A core group of 25 was initially convened in Ben Lomand, California, in September 2000 by Brad deGraf. They were invited to address ways of using the Internet to establish a global network of people concerned about the future of the environment that could number in the many millions. Rarely had engineers, activists, and media professionals been part of the same extended conversation about the potential of networked digital communications to serve the public interest. The dialogue was more than stimulating, and the group decided to form an organization to give further shape to ideas introduced that weekend. A half dozen more weekend sessions followed over the next 18 months, as well as a flurry of off-line conversations and parallel projects. In time, a vision took shape for a next- generation online community that provides people across the globe with better tools to take part in democratic action and to collaboratively organize their resources in order to promote environmental sustainability. The ASN is a core component of this broader vision, and each participant in the group discussions contributed to the development of this vision. The voting members of the group, which eventually took the name Link Tank, are: Debra Amador, Juliette Beck, Jack Bradin, Bruce Cahan, Brad deGraf, Bonnie DeVarco, Andres Edwards, Jim Fournier, Steve Foster, Chris Gallagher, Lev Gonick, Jan Hauser, James Hung, Allen Hunt-Badiner, Ken Jordan, Michael Litz , Richard Perl, Christie Rothenberg , Neil Sieling, Greg Steltenpohl, Elizabeth Thompson, Hardin Tibbs, Michael Tolson, Amie Weinberg, and Nate Zelnick. Among the informal advisors to the group, who took part in some of the meetings or online discussions, were: Jeffrey Alexrod, Owen Davis, Gerald de Jong, Tom Laskawy , Tom Munnecke, Robin Mudge, Ellen Pearlman, Jonathan Peizer, Richard White, and Duncan Work.

In January, 2002, Link Tank commissioned Jan Hauser, Steven Foster, and Ken Jordan to prepare a white paper that demonstrates the feasibility of the ASN's vision of online community by describing a technical architecture that could achieve this vision. Jan and Steve developed the core elements of the ASN architecture, and wrote a first draft describing its technical components. Ken wrote a much-expanded second draft based on the first, helped to complete the technical architecture, and added the political analysis. The three revised the paper in collaboration.

The authors would like to thank Cynthia Typaldos and Mark S. Miller for their contributions to the ideas expressed in this paper. We also want to acknowledge the influence of Dee Hock's theoretical work on chaordic organizations. Our gratitude goes out to the Chaordic Commons, whose support was instrumental in the preparation of this paper. Lastly, we extend our thanks to Neil Sieling, who managed this process for the Link Tank, for his valuable feedback to drafts in revision.

<p align="right"><sub><a href="#page-title"><em>^ Table of Contents</em></a></sub></p>

### B. About The Authors
**Ken Jordan**
Ken Jordan is one of the pioneers of Web-based multimedia. In 1995 he led the development and served as founding editorial director of SonicNet.com, the first multimedia music zine. SonicNet was named best website of 1995 by Entertainment Weekly and won the first Webby award for music site before becoming a property of MTV. In 1996 Mr. Jordan became creative director of Icon New Media, publisher of two seminal, award-winning online magazines: the general interest zine Word.com, and the action sports site Charged.com. In 1999, he co-founded the public interest portal MediaChannel.org, in partnership with Globalvision and the international civil society network OneWorld.net; it was OneWorld's first U.S. based project. He is currently a writer and digital media consultant based in New York, and Director of the Art and Culture Network.

Ken is co-editor of Multimedia: From Wagner to Virtual Reality (W.W. Norton, 2001), an anthology of seminal articles that trace the "secret" history of digital multimedia; the book is widely taught at colleges and universities around the world. Outside the digital realm, he collaborated with the playwright and director Richard Foreman on the book Unbalancing Acts: Foundations for a Theater (Pantheon, 1992).

**Jan Hauser**

Jan Hauser is currently a Business Development Manager at Science Application International Corporation (SAIC) and is also a visiting professor at the Naval Postgraduate School, in Monterey California. At SAIC Jan focuses on business development of SAIC’s Latent Symantec Indexing Product (LSI). This product is capable of discovering and matching “concepts” which it discovers in unstructured text. LSI functions independent of what native language these concepts are expressed in and also works independent of the various terminologies used by individuals to express their concepts.

Jan was formerly principle architect at Sun Microsystems where he was responsible for Sun’s membership in The Santa Fe Institute (SFI). Jan has been a catalyst for the application of Complexity Science to business, social, and environmental problems. In this pursuit he co-organized a workshop with The Institute For The Future (IFTF) - Growing At the Edge: The New Corporate Structures for Innovation and the Challenge of Governance.
Jan has worked on the development of Sun’s architecture for automated markets, Electronic Trade Exchanges, and principals that lead to the emergence of "communities" of trading partners. He currently spends much of his personal time working on problems of "Global Sustainability." Jan has also worked with Dee Hock, founder of VISA International, in the development of new organizational models and implementations of so called "Chaordic," or self- organizing institutional forms, which were included in Sun’s Jini community, design. This work led Jan to focus his energies on promoting the development and adoption of technologies that would support the emergence of "Chaord Light," a means of exploiting the internet in catalyzing latent “Social Networks” based on shared or complementary interests and capabilities combined with the transitive nature of trust amongst people who know each other indirectly through our “six degrees” of our personal knowledge and connectivity.

**Steven Foster**
Steven Foster is a pioneer in Internet resource discovery. In 1992 he designed and developed the first comprehensive Internet search engine, Veronica, which became the most active service on the Internet in 1994. He has consulted widely in the application of search technology to education and telecommunications. In 1998 he began work on applying markup and metadata to improve automated comparison of structured professional vocabularies. At present Steven researches the applications of semantic technologies to email analysis and web services.
 
