---
date: 2020-12-01
title: Ethereum Oasis Open Project • Baseline Protocol
description: To develop clear, open standards, high-quality documentation, and shared test suites that facilitate new features and enhancements to the Ethereum protocol.
excerpt: >
    The Ethereum OASIS Open Project is an OASIS Open Project that exists to provide a neutral forum for diverse stakeholders to create high-quality specifications that facilitate Ethereum’s longevity, interoperability, and ease of integration. The Ethereum OASIS Project intends to develop clear, open standards, high-quality documentation, and shared test suites that facilitate new features and enhancements to the Ethereum protocol.
categories: ["Ethereum","Web Standards"]
tags: ["OASIS","Ethereum","Enterprise Ethereum Alliance","Ethereum Foundation","ConsenSys","Chainlink","Nethermind","Provide","Unibright","Ernst & Young","Microsoft","Limechain"]
last_modified_at: 2020-12-01
header:
  image: /images/oasis-ethereum.webp
  teaser: /images/baseline-teaser.webp
toc: false
permalink: web-standards/oasis-open/ethereum-oasis/
redirect_from: ethereum/web%20standards/ethereum-oasis/
---

**Oasis Open Projects:** [Website](https://oasis-open-projects.org/) • [Blog](https://oasis-open-projects.org/category/blog/)\
**Ethereum Oasis:** [GitHub](https://github.com/ethereum-oasis) • [Baseline](https://www.baseline-protocol.org/) • [Docs](https://docs.baseline-protocol.org/) • [Twitter](https://twitter.com/baselineproto) • [Slack](https://communityinviter.com/apps/ethereum-baseline/join-us)

[Ethereum OASIS Open Project Charter](https://github.com/ethereum-oasis/oasis-open-project/blob/master/PROJECT_CHARTER.md)
> The EIP process has led to a rich diverse engagement of developers in improving Ethereum - this decentralized ability of all to contribute ideas and features is a benefit to the ecosystem. This process has also led to EIPs of varying specificity, application, and quality, which presents a challenge to developers and organizations looking to adopt the most interoperable standards.
> 
> The Ethereum OASIS Open Project seeks to address this problem and improve the interoperability of implementations for all. Working within a process that is predictable, fair, transparent, and time-tested, the Ethereum OASIS Project will provide a forum for producing standards in a style familiar to corporate contributors. Additionally, we wish for an Ethereum standard to be able to be blessed as more canonical among the sometimes mutually-exclusive EIPs. Finally, we also wish to ease the transition of technology and standards from Mainnet to private and/or permissioned chains such as those from the Enterprise Ethereum Alliance.


## Posts 
- [OASIS Introduces Open Projects Program to Bridge Open Source and Standards Development](https://oasis-open-projects.org/introducing-open-projects/)
  > OASIS, a global nonprofit consortium, today announced the launch of Open Projects, the first-of-its-kind program that creates a more transparent and collaborative future for open source and standards development. Open Projects gives communities the power to develop what they choose–APIs, code, specifications, reference implementations, guidelines– in one place, under open source licenses, with a path to recognition in global policy and procurement.
* [EY and ConsenSys Announce Formation of Baseline Protocol Initiative](https://consensys.net/blog/press-release/ey-and-consensys-announce-formation-of-baseline-protocol-initiative-to-make-ethereum-mainnet-safe-and-effective-for-enterprises/) - Industry leaders donate code to public domain through non-profit standards body, OASIS, and join fourteen founding organizations to further develop Baseline Protocol.
  > New York, NY — Today, EY and ConsenSys announced the formation of the Baseline Protocol in collaboration with Microsoft. The Baseline Protocol is an open source initiative that combines advances in cryptography, messaging, and blockchain to deliver secure and private business processes at low cost via the public Ethereum Mainnet. The protocol will enable confidential and complex collaboration between enterprises without leaving any sensitive data on-chain. The work will be governed by the Ethereum-Oasis Project, which is managed by OASIS and funded by the Ethereum Foundation and the Enterprise Ethereum Alliance.
* [EY, ConsenSys, Microsoft unveil Baseline, a path for enterprises to public blockchain](https://www.ledgerinsights.com/baseline-protocol-ey-consensys-microsoft-enterprises-public-blockchain/)
  > * Baseline Protocol aims to address privacy issues to encourage enterprise adoption of public Ethereum
  > * Is a set of tools to completely cloak transactions, smart contract logic and communications via the Ethereum Mainnet
  > * Using Zero Knowledge Proofs offers granular privacy and p2p communication
  > * Aims to replicate some of the key features of traditional enterprise middleware, but for transactions between companies
  > * EY and ConsenSys vision is for one blockchain (Ethereum), like there is one internet
* [The Baseline Protocol Explained](https://medium.com/limechain/the-baseline-protocol-explained-d40ee01588ba) (Limechain)
  > The Baseline Protocol is an open-source initiative aimed at the synchronization of private business processes, like document exchange, via a public blockchain. It leverages cryptography techniques like zero-knowledge proofs and signatures, peer-to-peer messaging protocols, and the blockchain to achieve its goals.
  > 
  > On one hand, it is designed with confidentiality, privacy, and data security in mind. The mixture of technologies is aligned in such a way that none of your sensitive data is leaked. This data stays safely with you and your counter-parties. Outsiders looking in will not know what process is being executed, who are the actors, or what goods are exchanged.
  > 
  > On the other hand, the protocol is designed with complex interactions in mind. Inter-company business processes involve many stops and checks and are never straightforward. The protocol will allow you to describe and accommodate your business process however complex it is.
- [Baseline Protocol Secures Business Process Automation Across SAP and Microsoft Dynamics](https://oasis-open-projects.org/open-source-proof-of-concept-ethereum-mainnet/)
  > The procurement use case in the demo released today highlights how two Enterprise Resource Planning (ERP) systems, Microsoft Dynamics and SAP can maintain consistency with each other using blockchain technology without exposing information about business activities or relationships to competitors or the public. Its use of the public Mainnet reduces capital expense while increasing operational integrity when automating business processes across multiple companies.\
  > [...]\
  > Several companies worked together to create the demo. Unibright extracted the domain model from the Unibright connector, set up a connection proxy to the Provide/Baseline stack and integrated SAP. Provide adapted the Baseline Protocol as a standard within the Provide stack, including its secure messaging infrastructure service. This was critical as it enabled orchestration of the baseline containers and management of key material. Envision Blockchain configured and integrated the Microsoft Dynamics 365 Finance and Supply Chain Management business apps.
- [Baseline Protocol integrates Google Sheets and Microsoft Dynamics 365](https://oasis-open-projects.org/baseline-protocol-initiative-integrates-google-sheets-and-microsoft-dynamics-365-using-public-ethereum-blockchain/)
  > Businesses spend hundreds of millions of dollars on ERP, CRM, and other internal systems of record. Failure to properly synchronize these systems between organizations causes disputes, lost inventory, inflated capital costs, regulatory actions, and other value leakages. To avoid these problems, systems need a common frame of reference, an integration layer that typically only the largest partnerships can afford. The baseline approach uses the public Ethereum Mainnet as its common frame of reference, which means it’s always on, companies can’t be locked out, and firms only pay for what they use.
- [Baseline Protocol Achieves Key Milestone with Release of v0.1 Implementation for Enterprise IT and the Ethereum Public Blockchain](https://oasis-open-projects.org/baseline-protocol-v01/)
  > Today’s release of Baseline Protocol v0.1 represents a significant milestone, because it provides a set of standard interfaces for developers to implement solutions easily and for vendors to provide their own modules that comply with the specification. Official OASIS standards development based on the v0.1 reference implementation will commence in September.

## GitHub

[ethereum-oasis](https://github.com/ethereum-oasis)
- [oasis-open-project](https://github.com/ethereum-oasis/oasis-open-project) - Everything related to the Ethereum OASIS Open Project
- [baseline](https://github.com/ethereum-oasis/baseline)
  > The Baseline Protocol is an open source initiative that combines advances in cryptography, messaging, and blockchain to execute secure and private business processes at low cost via the public Ethereum Mainnet. The protocol will enable confidential and complex collaboration between enterprises without leaving any sensitive data on-chain
- [baseline-website](https://github.com/ethereum-oasis/baseline-website) - a hugo site
- [eth1.x-JSON-RPC-API-standard](https://github.com/ethereum-oasis/eth1.x-JSON-RPC-API-standard)
- [baseline-roadmap](https://github.com/ethereum-oasis/baseline-roadmap)