---
date: 2020-11-09
title:  World Wide Web Consortium
description: An international community that develops open standards to ensure the long-term growth of the Web.
excerpt: "First started as an IETF application area at the beginning of 1990, the Web standard stack, given its foreseen volume and applicative nature on top of the Internet protocols, quickly spun off its own forum. The W3C then laid the foundations of the Web with the development of HTML 4 and XML at the end of the last century. It still works closely with IETF today, on the HTTP or URL specifications and in other areas of common interest (e.g. crypto, security, video)."
layout: single
permalink: web-standards/w3c/
canonical_url: 'https://decentralized-id.com/web-standards/w3c/'
categories: ["Web Standards","Organizations"]
tags: ["W3C","Credentials Community Group","JSON-LD","WebAuthN","DID","Verifiable Credentials","Veres One","BTCR","Linked Data"]
header:
  image: /images/w3c_banner.webp
  teaser: /images/w3c_teaser.webp
last_modified_at: 2020-11-22
---

**[World Wide Web Consortium(W3C)](https://www.w3.org/) • [Twitter](https://twitter.com/w3c) • [GitHub](https://github.com/w3c) • [LinkedIn](https://www.linkedin.com/company/w3c/)**

* [ICANN WIki](https://icannwiki.org/W3C)
  > First started as an IETF application area at the beginning of 1990, the Web standard stack, given its foreseen volume and applicative nature on top of the Internet protocols, quickly spun off its own forum. The W3C then laid the foundations of the Web with the development of HTML 4 and XML at the end of the last century. It still works closely with IETF today, on the HTTP or URL specifications and in other areas of common interest (e.g. crypto, security, video). 

## Consortium

> The [World Wide Web Consortium (W3C)](https://www.w3.org/Consortium/) is an international community where Member organizations, a full-time staff, and the public work together to develop Web standards. Led by Web inventor and Director Tim Berners-Lee and CEO Jeffrey Jaffe, W3C's mission is to lead the Web to its full potential.

### [Mission](https://www.w3.org/Consortium/mission)

> On 29 August 2012 five leading global organizations jointly signed an agreement to affirm and adhere to a set of Principles in support of The Modern Paradigm for Standards; an open and collectively empowering model that will help radically improve the way people around the world develop new technologies and innovate for humanity. Learn more about OpenStand: the modern paradigm for standards.

### [Facts](https://www.w3.org/Consortium/facts.html)

> In 1989, Tim Berners-Lee invented the World Wide Web (see the original proposal). He coined the term "World Wide Web," wrote the first World Wide Web server, "httpd," and the first client program (a browser and editor), "WorldWideWeb," in October 1990. He wrote the first version of the "HyperText Markup Language" (HTML), the document formatting language with the capability for hypertext links that became the primary publishing format for the Web. His initial specifications for URIs, HTTP, and HTML were refined and discussed in larger circles as Web technology spread.

### [Standards](https://www.w3.org/standards/)

> W3C standards define an Open Web Platform for application development that has the unprecedented potential to enable developers to build rich interactive experiences, powered by vast data stores, that are available on any device. Although the boundaries of the platform continue to evolve, industry leaders speak nearly in unison about how HTML5 will be the cornerstone for this platform. But the full strength of the platform relies on many more technologies that W3C and its partners are creating, including CSS, SVG, WOFF, the Semantic Web stack, XML, and a variety of APIs.

## Info

* [W3C Workshop on Strong Authentication & Identity](https://www.w3.org/Security/strong-authentication-and-identity-workshop/report.html)
* [A Public Identity](https://www.w3.org/DesignIssues/PublicIdentity.html) - Tim Berners-Lee 2018
  > The world of the last few years has been buzzing with the need for personal privacy a world in which personal data is typically abused by large corporations on the (mistaken) belief that this is the only business model in a connected world. It seems to have got to the point where there has been so much focus on protecting the identity of an individual online that we have actually made it difficult, frustratingly and unnecessarily difficult, to actually claim a completely public identity online.
* [Call for Participation in Digital Identity Community Group](https://www.w3.org/community/dic/2019/06/20/call-for-participation-in-digital-identity-community-group/)
  > The mission of the W3C Digital Identity Community Group is to identify and resolve real world identity issues, to explore and build a more secure trusted digital identity ecosystem on internet for people, organizations and things fully controlling, protecting and expressing their identity. Our work focuses on the ecosystem’s scalability, interoperability, mobility, security and privacy. We intend to integrate interoperable identity solutions, systems and networks in our ecosystem.

## Community and Working Groups on GitHub
### Verifiable Claims Working Group (VC-WG) 

[Verifiable Claims WG - Mailing List](https://lists.w3.org/Archives/Public/public-vc-wg/) (and archives)

* [w3c/verifiable-claims](https://github.com/w3c/verifiable-claims) - W3C Verifiable Claims Working Group.
* [w3c/vc-data-model](https://github.com/w3c/vc-data-model) -Verifiable Claims Data Model and Representations specification.
* [w3c/vc-use-cases](https://github.com/w3c/vc-use-cases) - Verifiable Claims Use Cases.
* [w3c/vc-test-suite](https://github.com/w3c/vc-test-suite) - Verifiable Claims WG Test Suite.
* [w3c/vc-imp-guide](https://github.com/w3c/vc-imp-guide) - Verifiable Credentials Implementation Guidelines

### Credentials Community Group (CCG)

[Public mailing list for the Credentials Community Group](http://lists.w3.org/Archives/Public/public-credentials/) (and archives) - Anyone may read or write to this list.
* [w3c-ccg/meetings](https://github.com/w3c-ccg/meetings) CCG Meeting Transcripts
* [w3c-ccg/community](https://github.com/w3c-ccg/community) - CCG Community Repo
* [w3c-ccg/announcements](https://github.com/w3c-ccg/announcements) - CCG Announcements
* [w3c-ccg/w3c-ccg-process](https://github.com/w3c-ccg/w3c-ccg-process)
* [w3c-ccg/registries-process](https://github.com/w3c-ccg/registries-process)

#### DID

* [w3c-ccg/did-primer](https://github.com/w3c-ccg/did-primer) - A Primer for Decentralized Identifiers
* [w3c-ccg/did-spec](https://github.com/w3c-ccg/did-spec) - Decentralized Identifier (DID) 1.0 Specification - Data Model and Syntax
* [w3c-ccg/did-resolution](https://github.com/w3c-ccg/did-resolution) Spec 1.0
* [w3c-ccg/did-use-cases](https://github.com/w3c-ccg/did-use-cases)
* [w3c-ccg/did-method-registry](https://github.com/w3c-ccg/did-method-registry) - a list of all known DID Methods and their current level of maturity.
  * [w3c-ccg/didm-btcr](https://github.com/w3c-ccg/didm-btcr) - WORK ITEM: BTCR DID Method Spec
  * [w3c-ccg/didm-veres-one](https://github.com/w3c-ccg/didm-veres-one) - Veres One Decentralized Identifier Method Specification
* [w3c-ccg/did-wg-proposal](https://github.com/w3c-ccg/did-wg-proposal) - Proposal to W3C membership for a DID Working Group.
  * [w3c-ccg/did-wg-charter](https://github.com/w3c-ccg/did-wg-charter) - EXPERIMENTAL charter for the W3C Decentralized Identifier Working Group 
* [w3c-ccg/did-hackathon-2018](https://github.com/w3c-ccg/did-hackathon-2018)
* [w3c-ccg/data-minimization](https://github.com/w3c-ccg/data-minimization) - Data Minimization, Selective Disclosure, and Progressive Trust
* [w3c-ccg/credential-handler-api](https://github.com/w3c-ccg/credential-handler-api)
* [w3c-ccg/amira](https://github.com/w3c-ccg/amira) - Amira Engagement Model.
* [w3c-ccg/functional-identity](https://github.com/w3c-ccg/functional-identity)

#### Verifiable Credentials

* [w3c-ccg/vc-status-registry](https://github.com/w3c-ccg/vc-status-registry) - REGISTRY: The Verifiable Credentials Status Scheme Registry.
* [w3c-ccg/edu_occ_verifiable_credentials](https://github.com/w3c-ccg/edu_occ_verifiable_credentials) - WORK ITEM: Drafts and Ideas of Educational and Occupational Verifiable Credentials.
* [w3c-ccg/vc-examples](https://github.com/w3c-ccg/vc-examples) - WORK ITEM: Verifiable Credentials Examples

#### Linked Data
* [w3c-ccg/ocap-ld](https://github.com/w3c-ccg/ocap-ld) - WORK ITEM: Linked Data Object Capabilities specification
* [w3c-ccg/ld-cryptosuite-registry](https://github.com/w3c-ccg/ld-cryptosuite-registry) - REGISTRY: Linked Data Keys Registry

### WebAuthN WG

* [w3c/webauthn](https://github.com/w3c/webauthn) - Web Authentication: An API for accessing Public Key Credentials
  * [w3c.github.io/webauthn/](https://w3c.github.io/webauthn/) (website)
* [w3c/webauthn-pay](https://github.com/w3c/webauthn-pay) - Joint task force of Web Authentication WG and Web Payments WG

### JSON-LD WG
- [w3c/json-ld-wg](https://github.com/w3c/json-ld-wg) • [website](https://www.w3.org/2018/json-ld-wg/)
- [w3c/json-ld-framing](https://github.com/w3c/json-ld-framing) - JSON-LD 1.1 Framing Specification
- [w3c/json-ld-api](https://github.com/w3c/json-ld-api) - JSON-LD 1.1 Processing Algorithms and API Specification
- [w3c/json-ld-syntax](https://github.com/w3c/json-ld-syntax) - JSON-LD 1.1 Specification
* [w3c/json-ld-bp](https://github.com/w3c/json-ld-bp) JSON-LD 1.1 Best Practices Note [w3c.github.io/json-ld-bp](https://w3c.github.io/json-ld-bp/)
* [w3c/json-ld-rc](https://github.com/w3c/json-ld-rc)

### W3C DID Working Group

> The mission of the Decentralized Identifier Working Group is to standardize the DID URI scheme, the data model and syntax of DID Documents, which contain information related to DIDs that enable the aforementioned initial use cases, and the requirements for DID Method specifications.

- [w3c/did-wg](https://github.com/w3c/did-wg) 
  - [Website](https://www.w3.org/2019/did-wg/)
  - [Charter](https://w3c-ccg.github.io/did-wg-charter/)
- [did-core](https://github.com/w3c/did-core) - [site](https://w3c.github.io/did-core/) 
  > W3C Decentralized Identifier Specification v1.0
- [.well-known](https://github.com/decentralized-identity/.well-known) - [site](https://identity.foundation/.well-known)
  > Specs and documentation for all DID-related /.well-known resources
- [did-spec-registries](https://github.com/w3c/did-spec-registries) - [site](https://w3c.github.io/did-spec-registries/)
  > DID Spec Registry (Note)
- [did-use-cases](https://github.com/w3c/did-use-cases) - [site](https://w3c.github.io/did-use-cases/)
  > Decentralized Identifier Use Cases and Requirements v1.0
- [did-wg](https://github.com/w3c/did-wg) - [site](https://www.w3.org/2019/did-wg/)
  > Home page of the Decentralized Identifier Working Group
- [did-test-suite](https://github.com/w3c/did-test-suite) - [site](https://w3c.github.io/did-test-suite/)
  > W3C DID Test Suite and Implementation Report
- [did-imp-guide](https://github.com/w3c/did-imp-guide) - [site](https://w3c.github.io/did-imp-guide/)
  > DID Implementation Guide (Note)
- [did-rubric](https://github.com/w3c/did-rubric) - [site](https://w3c.github.io/did-rubric/)
  > W3C Decentralized Characteristics Rubric v1.0
